#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.LogisticsAccountStatusDTO import LogisticsAccountStatusDTO


class AlipayOpenInstantdeliveryAccountCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenInstantdeliveryAccountCreateResponse, self).__init__()
        self._logistics_account_status = None

    @property
    def logistics_account_status(self):
        return self._logistics_account_status

    @logistics_account_status.setter
    def logistics_account_status(self, value):
        if isinstance(value, list):
            self._logistics_account_status = list()
            for i in value:
                if isinstance(i, LogisticsAccountStatusDTO):
                    self._logistics_account_status.append(i)
                else:
                    self._logistics_account_status.append(LogisticsAccountStatusDTO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenInstantdeliveryAccountCreateResponse, self).parse_response_content(response_content)
        if 'logistics_account_status' in response:
            self.logistics_account_status = response['logistics_account_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CplifeRoomDetail import CplifeRoomDetail


class AlipayEcoCplifeRoominfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoCplifeRoominfoQueryResponse, self).__init__()
        self._room_info = None
        self._total_room_number = None

    @property
    def room_info(self):
        return self._room_info

    @room_info.setter
    def room_info(self, value):
        if isinstance(value, list):
            self._room_info = list()
            for i in value:
                if isinstance(i, CplifeRoomDetail):
                    self._room_info.append(i)
                else:
                    self._room_info.append(CplifeRoomDetail.from_alipay_dict(i))
    @property
    def total_room_number(self):
        return self._total_room_number

    @total_room_number.setter
    def total_room_number(self, value):
        self._total_room_number = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoCplifeRoominfoQueryResponse, self).parse_response_content(response_content)
        if 'room_info' in response:
            self.room_info = response['room_info']
        if 'total_room_number' in response:
            self.total_room_number = response['total_room_number']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BankGoodsDetail(object):

    def __init__(self):
        self._goods_desc = None
        self._goods_id = None
        self._goods_name = None
        self._price = None
        self._quantity = None

    @property
    def goods_desc(self):
        return self._goods_desc

    @goods_desc.setter
    def goods_desc(self, value):
        self._goods_desc = value
    @property
    def goods_id(self):
        return self._goods_id

    @goods_id.setter
    def goods_id(self, value):
        self._goods_id = value
    @property
    def goods_name(self):
        return self._goods_name

    @goods_name.setter
    def goods_name(self, value):
        self._goods_name = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def quantity(self):
        return self._quantity

    @quantity.setter
    def quantity(self, value):
        self._quantity = value


    def to_alipay_dict(self):
        params = dict()
        if self.goods_desc:
            if hasattr(self.goods_desc, 'to_alipay_dict'):
                params['goods_desc'] = self.goods_desc.to_alipay_dict()
            else:
                params['goods_desc'] = self.goods_desc
        if self.goods_id:
            if hasattr(self.goods_id, 'to_alipay_dict'):
                params['goods_id'] = self.goods_id.to_alipay_dict()
            else:
                params['goods_id'] = self.goods_id
        if self.goods_name:
            if hasattr(self.goods_name, 'to_alipay_dict'):
                params['goods_name'] = self.goods_name.to_alipay_dict()
            else:
                params['goods_name'] = self.goods_name
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.quantity:
            if hasattr(self.quantity, 'to_alipay_dict'):
                params['quantity'] = self.quantity.to_alipay_dict()
            else:
                params['quantity'] = self.quantity
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BankGoodsDetail()
        if 'goods_desc' in d:
            o.goods_desc = d['goods_desc']
        if 'goods_id' in d:
            o.goods_id = d['goods_id']
        if 'goods_name' in d:
            o.goods_name = d['goods_name']
        if 'price' in d:
            o.price = d['price']
        if 'quantity' in d:
            o.quantity = d['quantity']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingCampaignCertCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingCampaignCertCreateResponse, self).__init__()
        self._lot_number = None

    @property
    def lot_number(self):
        return self._lot_number

    @lot_number.setter
    def lot_number(self, value):
        self._lot_number = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingCampaignCertCreateResponse, self).parse_response_content(response_content)
        if 'lot_number' in response:
            self.lot_number = response['lot_number']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ReportInfo import ReportInfo


class AnttechBlockchainDefinInsuranceReportQueryResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainDefinInsuranceReportQueryResponse, self).__init__()
        self._parm = None
        self._report_info_list = None
        self._trade_no = None

    @property
    def parm(self):
        return self._parm

    @parm.setter
    def parm(self, value):
        self._parm = value
    @property
    def report_info_list(self):
        return self._report_info_list

    @report_info_list.setter
    def report_info_list(self, value):
        if isinstance(value, list):
            self._report_info_list = list()
            for i in value:
                if isinstance(i, ReportInfo):
                    self._report_info_list.append(i)
                else:
                    self._report_info_list.append(ReportInfo.from_alipay_dict(i))
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainDefinInsuranceReportQueryResponse, self).parse_response_content(response_content)
        if 'parm' in response:
            self.parm = response['parm']
        if 'report_info_list' in response:
            self.report_info_list = response['report_info_list']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceDataMonitordeviceQualitycenterModifyModel(object):

    def __init__(self):
        self._asset_id = None
        self._fault_type = None
        self._invoke_id = None
        self._quality_center_id = None
        self._result = None
        self._result_date = None
        self._result_msg = None

    @property
    def asset_id(self):
        return self._asset_id

    @asset_id.setter
    def asset_id(self, value):
        self._asset_id = value
    @property
    def fault_type(self):
        return self._fault_type

    @fault_type.setter
    def fault_type(self, value):
        self._fault_type = value
    @property
    def invoke_id(self):
        return self._invoke_id

    @invoke_id.setter
    def invoke_id(self, value):
        self._invoke_id = value
    @property
    def quality_center_id(self):
        return self._quality_center_id

    @quality_center_id.setter
    def quality_center_id(self, value):
        self._quality_center_id = value
    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, value):
        self._result = value
    @property
    def result_date(self):
        return self._result_date

    @result_date.setter
    def result_date(self, value):
        self._result_date = value
    @property
    def result_msg(self):
        return self._result_msg

    @result_msg.setter
    def result_msg(self, value):
        self._result_msg = value


    def to_alipay_dict(self):
        params = dict()
        if self.asset_id:
            if hasattr(self.asset_id, 'to_alipay_dict'):
                params['asset_id'] = self.asset_id.to_alipay_dict()
            else:
                params['asset_id'] = self.asset_id
        if self.fault_type:
            if hasattr(self.fault_type, 'to_alipay_dict'):
                params['fault_type'] = self.fault_type.to_alipay_dict()
            else:
                params['fault_type'] = self.fault_type
        if self.invoke_id:
            if hasattr(self.invoke_id, 'to_alipay_dict'):
                params['invoke_id'] = self.invoke_id.to_alipay_dict()
            else:
                params['invoke_id'] = self.invoke_id
        if self.quality_center_id:
            if hasattr(self.quality_center_id, 'to_alipay_dict'):
                params['quality_center_id'] = self.quality_center_id.to_alipay_dict()
            else:
                params['quality_center_id'] = self.quality_center_id
        if self.result:
            if hasattr(self.result, 'to_alipay_dict'):
                params['result'] = self.result.to_alipay_dict()
            else:
                params['result'] = self.result
        if self.result_date:
            if hasattr(self.result_date, 'to_alipay_dict'):
                params['result_date'] = self.result_date.to_alipay_dict()
            else:
                params['result_date'] = self.result_date
        if self.result_msg:
            if hasattr(self.result_msg, 'to_alipay_dict'):
                params['result_msg'] = self.result_msg.to_alipay_dict()
            else:
                params['result_msg'] = self.result_msg
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceDataMonitordeviceQualitycenterModifyModel()
        if 'asset_id' in d:
            o.asset_id = d['asset_id']
        if 'fault_type' in d:
            o.fault_type = d['fault_type']
        if 'invoke_id' in d:
            o.invoke_id = d['invoke_id']
        if 'quality_center_id' in d:
            o.quality_center_id = d['quality_center_id']
        if 'result' in d:
            o.result = d['result']
        if 'result_date' in d:
            o.result_date = d['result_date']
        if 'result_msg' in d:
            o.result_msg = d['result_msg']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityProdHahaTestdddQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityProdHahaTestdddQueryResponse, self).__init__()
        self._haha = None

    @property
    def haha(self):
        return self._haha

    @haha.setter
    def haha(self, value):
        self._haha = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityProdHahaTestdddQueryResponse, self).parse_response_content(response_content)
        if 'haha' in response:
            self.haha = response['haha']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MaintainBizOrderServer(object):

    def __init__(self):
        self._order_server_id = None
        self._origin_cost = None
        self._out_product_id = None
        self._real_cost = None
        self._sale_num = None
        self._service_category_id = None

    @property
    def order_server_id(self):
        return self._order_server_id

    @order_server_id.setter
    def order_server_id(self, value):
        self._order_server_id = value
    @property
    def origin_cost(self):
        return self._origin_cost

    @origin_cost.setter
    def origin_cost(self, value):
        self._origin_cost = value
    @property
    def out_product_id(self):
        return self._out_product_id

    @out_product_id.setter
    def out_product_id(self, value):
        self._out_product_id = value
    @property
    def real_cost(self):
        return self._real_cost

    @real_cost.setter
    def real_cost(self, value):
        self._real_cost = value
    @property
    def sale_num(self):
        return self._sale_num

    @sale_num.setter
    def sale_num(self, value):
        self._sale_num = value
    @property
    def service_category_id(self):
        return self._service_category_id

    @service_category_id.setter
    def service_category_id(self, value):
        self._service_category_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.order_server_id:
            if hasattr(self.order_server_id, 'to_alipay_dict'):
                params['order_server_id'] = self.order_server_id.to_alipay_dict()
            else:
                params['order_server_id'] = self.order_server_id
        if self.origin_cost:
            if hasattr(self.origin_cost, 'to_alipay_dict'):
                params['origin_cost'] = self.origin_cost.to_alipay_dict()
            else:
                params['origin_cost'] = self.origin_cost
        if self.out_product_id:
            if hasattr(self.out_product_id, 'to_alipay_dict'):
                params['out_product_id'] = self.out_product_id.to_alipay_dict()
            else:
                params['out_product_id'] = self.out_product_id
        if self.real_cost:
            if hasattr(self.real_cost, 'to_alipay_dict'):
                params['real_cost'] = self.real_cost.to_alipay_dict()
            else:
                params['real_cost'] = self.real_cost
        if self.sale_num:
            if hasattr(self.sale_num, 'to_alipay_dict'):
                params['sale_num'] = self.sale_num.to_alipay_dict()
            else:
                params['sale_num'] = self.sale_num
        if self.service_category_id:
            if hasattr(self.service_category_id, 'to_alipay_dict'):
                params['service_category_id'] = self.service_category_id.to_alipay_dict()
            else:
                params['service_category_id'] = self.service_category_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MaintainBizOrderServer()
        if 'order_server_id' in d:
            o.order_server_id = d['order_server_id']
        if 'origin_cost' in d:
            o.origin_cost = d['origin_cost']
        if 'out_product_id' in d:
            o.out_product_id = d['out_product_id']
        if 'real_cost' in d:
            o.real_cost = d['real_cost']
        if 'sale_num' in d:
            o.sale_num = d['sale_num']
        if 'service_category_id' in d:
            o.service_category_id = d['service_category_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsSceneLifemssageSingleSendModel(object):

    def __init__(self):
        self._out_biz_no = None
        self._public_id = None
        self._push_context = None
        self._template_context = None
        self._template_id = None
        self._to_user_id = None

    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def public_id(self):
        return self._public_id

    @public_id.setter
    def public_id(self, value):
        self._public_id = value
    @property
    def push_context(self):
        return self._push_context

    @push_context.setter
    def push_context(self, value):
        self._push_context = value
    @property
    def template_context(self):
        return self._template_context

    @template_context.setter
    def template_context(self, value):
        self._template_context = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def to_user_id(self):
        return self._to_user_id

    @to_user_id.setter
    def to_user_id(self, value):
        self._to_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.public_id:
            if hasattr(self.public_id, 'to_alipay_dict'):
                params['public_id'] = self.public_id.to_alipay_dict()
            else:
                params['public_id'] = self.public_id
        if self.push_context:
            if hasattr(self.push_context, 'to_alipay_dict'):
                params['push_context'] = self.push_context.to_alipay_dict()
            else:
                params['push_context'] = self.push_context
        if self.template_context:
            if hasattr(self.template_context, 'to_alipay_dict'):
                params['template_context'] = self.template_context.to_alipay_dict()
            else:
                params['template_context'] = self.template_context
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        if self.to_user_id:
            if hasattr(self.to_user_id, 'to_alipay_dict'):
                params['to_user_id'] = self.to_user_id.to_alipay_dict()
            else:
                params['to_user_id'] = self.to_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneLifemssageSingleSendModel()
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'public_id' in d:
            o.public_id = d['public_id']
        if 'push_context' in d:
            o.push_context = d['push_context']
        if 'template_context' in d:
            o.template_context = d['template_context']
        if 'template_id' in d:
            o.template_id = d['template_id']
        if 'to_user_id' in d:
            o.to_user_id = d['to_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class XwbTestData(object):

    def __init__(self):
        self._s = None

    @property
    def s(self):
        return self._s

    @s.setter
    def s(self, value):
        self._s = value


    def to_alipay_dict(self):
        params = dict()
        if self.s:
            if hasattr(self.s, 'to_alipay_dict'):
                params['s'] = self.s.to_alipay_dict()
            else:
                params['s'] = self.s
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = XwbTestData()
        if 's' in d:
            o.s = d['s']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CreateMiniRequest import CreateMiniRequest


class AlipayOpenMiniIsvCreateModel(object):

    def __init__(self):
        self._create_mini_request = None

    @property
    def create_mini_request(self):
        return self._create_mini_request

    @create_mini_request.setter
    def create_mini_request(self, value):
        if isinstance(value, CreateMiniRequest):
            self._create_mini_request = value
        else:
            self._create_mini_request = CreateMiniRequest.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.create_mini_request:
            if hasattr(self.create_mini_request, 'to_alipay_dict'):
                params['create_mini_request'] = self.create_mini_request.to_alipay_dict()
            else:
                params['create_mini_request'] = self.create_mini_request
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniIsvCreateModel()
        if 'create_mini_request' in d:
            o.create_mini_request = d['create_mini_request']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppBillkeyUpgradeResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppBillkeyUpgradeResponse, self).__init__()
        self._bill_key = None
        self._biz_type = None
        self._charge_inst = None
        self._new_bill_key = None
        self._operation_type = None
        self._sub_biz_type = None

    @property
    def bill_key(self):
        return self._bill_key

    @bill_key.setter
    def bill_key(self, value):
        self._bill_key = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def new_bill_key(self):
        return self._new_bill_key

    @new_bill_key.setter
    def new_bill_key(self, value):
        self._new_bill_key = value
    @property
    def operation_type(self):
        return self._operation_type

    @operation_type.setter
    def operation_type(self, value):
        self._operation_type = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppBillkeyUpgradeResponse, self).parse_response_content(response_content)
        if 'bill_key' in response:
            self.bill_key = response['bill_key']
        if 'biz_type' in response:
            self.biz_type = response['biz_type']
        if 'charge_inst' in response:
            self.charge_inst = response['charge_inst']
        if 'new_bill_key' in response:
            self.new_bill_key = response['new_bill_key']
        if 'operation_type' in response:
            self.operation_type = response['operation_type']
        if 'sub_biz_type' in response:
            self.sub_biz_type = response['sub_biz_type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.RecItemInfo import RecItemInfo


class RecResultInfo(object):

    def __init__(self):
        self._code = None
        self._items = None
        self._msg = None
        self._position_id = None
        self._success = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def items(self):
        return self._items

    @items.setter
    def items(self, value):
        if isinstance(value, list):
            self._items = list()
            for i in value:
                if isinstance(i, RecItemInfo):
                    self._items.append(i)
                else:
                    self._items.append(RecItemInfo.from_alipay_dict(i))
    @property
    def msg(self):
        return self._msg

    @msg.setter
    def msg(self, value):
        self._msg = value
    @property
    def position_id(self):
        return self._position_id

    @position_id.setter
    def position_id(self, value):
        self._position_id = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.items:
            if isinstance(self.items, list):
                for i in range(0, len(self.items)):
                    element = self.items[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.items[i] = element.to_alipay_dict()
            if hasattr(self.items, 'to_alipay_dict'):
                params['items'] = self.items.to_alipay_dict()
            else:
                params['items'] = self.items
        if self.msg:
            if hasattr(self.msg, 'to_alipay_dict'):
                params['msg'] = self.msg.to_alipay_dict()
            else:
                params['msg'] = self.msg
        if self.position_id:
            if hasattr(self.position_id, 'to_alipay_dict'):
                params['position_id'] = self.position_id.to_alipay_dict()
            else:
                params['position_id'] = self.position_id
        if self.success:
            if hasattr(self.success, 'to_alipay_dict'):
                params['success'] = self.success.to_alipay_dict()
            else:
                params['success'] = self.success
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RecResultInfo()
        if 'code' in d:
            o.code = d['code']
        if 'items' in d:
            o.items = d['items']
        if 'msg' in d:
            o.msg = d['msg']
        if 'position_id' in d:
            o.position_id = d['position_id']
        if 'success' in d:
            o.success = d['success']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcoLicenseOcrIdentifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoLicenseOcrIdentifyResponse, self).__init__()
        self._address = None
        self._business = None
        self._captial = None
        self._establish_date = None
        self._name = None
        self._person = None
        self._reg_num = None
        self._valid_period = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def business(self):
        return self._business

    @business.setter
    def business(self, value):
        self._business = value
    @property
    def captial(self):
        return self._captial

    @captial.setter
    def captial(self, value):
        self._captial = value
    @property
    def establish_date(self):
        return self._establish_date

    @establish_date.setter
    def establish_date(self, value):
        self._establish_date = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def person(self):
        return self._person

    @person.setter
    def person(self, value):
        self._person = value
    @property
    def reg_num(self):
        return self._reg_num

    @reg_num.setter
    def reg_num(self, value):
        self._reg_num = value
    @property
    def valid_period(self):
        return self._valid_period

    @valid_period.setter
    def valid_period(self, value):
        self._valid_period = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoLicenseOcrIdentifyResponse, self).parse_response_content(response_content)
        if 'address' in response:
            self.address = response['address']
        if 'business' in response:
            self.business = response['business']
        if 'captial' in response:
            self.captial = response['captial']
        if 'establish_date' in response:
            self.establish_date = response['establish_date']
        if 'name' in response:
            self.name = response['name']
        if 'person' in response:
            self.person = response['person']
        if 'reg_num' in response:
            self.reg_num = response['reg_num']
        if 'valid_period' in response:
            self.valid_period = response['valid_period']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.UserLoginStatusDetail import UserLoginStatusDetail


class KoubeiMerchantKbcloudSubuserloginstatusQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMerchantKbcloudSubuserloginstatusQueryResponse, self).__init__()
        self._user_login_status = None

    @property
    def user_login_status(self):
        return self._user_login_status

    @user_login_status.setter
    def user_login_status(self, value):
        if isinstance(value, UserLoginStatusDetail):
            self._user_login_status = value
        else:
            self._user_login_status = UserLoginStatusDetail.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(KoubeiMerchantKbcloudSubuserloginstatusQueryResponse, self).parse_response_content(response_content)
        if 'user_login_status' in response:
            self.user_login_status = response['user_login_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceTransportTaxiDriverlevelQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceTransportTaxiDriverlevelQueryResponse, self).__init__()
        self._date_version = None
        self._driver_level = None
        self._driver_phone = None
        self._error_code = None
        self._error_message = None
        self._ext_info = None
        self._status = None

    @property
    def date_version(self):
        return self._date_version

    @date_version.setter
    def date_version(self, value):
        self._date_version = value
    @property
    def driver_level(self):
        return self._driver_level

    @driver_level.setter
    def driver_level(self, value):
        self._driver_level = value
    @property
    def driver_phone(self):
        return self._driver_phone

    @driver_phone.setter
    def driver_phone(self, value):
        self._driver_phone = value
    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_message(self):
        return self._error_message

    @error_message.setter
    def error_message(self, value):
        self._error_message = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceTransportTaxiDriverlevelQueryResponse, self).parse_response_content(response_content)
        if 'date_version' in response:
            self.date_version = response['date_version']
        if 'driver_level' in response:
            self.driver_level = response['driver_level']
        if 'driver_phone' in response:
            self.driver_phone = response['driver_phone']
        if 'error_code' in response:
            self.error_code = response['error_code']
        if 'error_message' in response:
            self.error_message = response['error_message']
        if 'ext_info' in response:
            self.ext_info = response['ext_info']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiQualityTestShieldCaselaunchApplyModel(object):

    def __init__(self):
        self._collection_ids = None
        self._dingding_token = None
        self._ext_infos = None

    @property
    def collection_ids(self):
        return self._collection_ids

    @collection_ids.setter
    def collection_ids(self, value):
        self._collection_ids = value
    @property
    def dingding_token(self):
        return self._dingding_token

    @dingding_token.setter
    def dingding_token(self, value):
        self._dingding_token = value
    @property
    def ext_infos(self):
        return self._ext_infos

    @ext_infos.setter
    def ext_infos(self, value):
        self._ext_infos = value


    def to_alipay_dict(self):
        params = dict()
        if self.collection_ids:
            if hasattr(self.collection_ids, 'to_alipay_dict'):
                params['collection_ids'] = self.collection_ids.to_alipay_dict()
            else:
                params['collection_ids'] = self.collection_ids
        if self.dingding_token:
            if hasattr(self.dingding_token, 'to_alipay_dict'):
                params['dingding_token'] = self.dingding_token.to_alipay_dict()
            else:
                params['dingding_token'] = self.dingding_token
        if self.ext_infos:
            if hasattr(self.ext_infos, 'to_alipay_dict'):
                params['ext_infos'] = self.ext_infos.to_alipay_dict()
            else:
                params['ext_infos'] = self.ext_infos
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiQualityTestShieldCaselaunchApplyModel()
        if 'collection_ids' in d:
            o.collection_ids = d['collection_ids']
        if 'dingding_token' in d:
            o.dingding_token = d['dingding_token']
        if 'ext_infos' in d:
            o.ext_infos = d['ext_infos']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SimpleMockModel import SimpleMockModel


class ComplextMockModel(object):

    def __init__(self):
        self._biz_model = None
        self._biz_num = None
        self._biz_type = None

    @property
    def biz_model(self):
        return self._biz_model

    @biz_model.setter
    def biz_model(self, value):
        if isinstance(value, SimpleMockModel):
            self._biz_model = value
        else:
            self._biz_model = SimpleMockModel.from_alipay_dict(value)
    @property
    def biz_num(self):
        return self._biz_num

    @biz_num.setter
    def biz_num(self, value):
        self._biz_num = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_model:
            if hasattr(self.biz_model, 'to_alipay_dict'):
                params['biz_model'] = self.biz_model.to_alipay_dict()
            else:
                params['biz_model'] = self.biz_model
        if self.biz_num:
            if hasattr(self.biz_num, 'to_alipay_dict'):
                params['biz_num'] = self.biz_num.to_alipay_dict()
            else:
                params['biz_num'] = self.biz_num
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ComplextMockModel()
        if 'biz_model' in d:
            o.biz_model = d['biz_model']
        if 'biz_num' in d:
            o.biz_num = d['biz_num']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KbdishPracticeInfo import KbdishPracticeInfo
from alipay.aop.api.domain.KbdishSkuInfo import KbdishSkuInfo
from alipay.aop.api.domain.KbdishMaterialBindingInfo import KbdishMaterialBindingInfo
from alipay.aop.api.domain.KbdishPropertyInfo import KbdishPropertyInfo


class KbdishInfo(object):

    def __init__(self):
        self._catetory_big_id = None
        self._catetory_small_id = None
        self._create_user = None
        self._cur_price_flag = None
        self._default_in_carts = None
        self._default_in_carts_detail = None
        self._dish_cuisine = None
        self._dish_detail_img_list = None
        self._dish_id = None
        self._dish_img = None
        self._dish_name = None
        self._dish_practice_list = None
        self._dish_sku_list = None
        self._dish_version = None
        self._en_remember_code = None
        self._ext_content = None
        self._goods_id = None
        self._material_binding_info_list = None
        self._merchant_id = None
        self._min_serving = None
        self._mini_add_num = None
        self._nb_remember_code = None
        self._not_count_threshold = None
        self._out_dish_id = None
        self._property_info_list = None
        self._remarks = None
        self._shop_id = None
        self._status = None
        self._tags = None
        self._type_big = None
        self._type_small = None
        self._unit_id = None
        self._update_user = None

    @property
    def catetory_big_id(self):
        return self._catetory_big_id

    @catetory_big_id.setter
    def catetory_big_id(self, value):
        self._catetory_big_id = value
    @property
    def catetory_small_id(self):
        return self._catetory_small_id

    @catetory_small_id.setter
    def catetory_small_id(self, value):
        self._catetory_small_id = value
    @property
    def create_user(self):
        return self._create_user

    @create_user.setter
    def create_user(self, value):
        self._create_user = value
    @property
    def cur_price_flag(self):
        return self._cur_price_flag

    @cur_price_flag.setter
    def cur_price_flag(self, value):
        self._cur_price_flag = value
    @property
    def default_in_carts(self):
        return self._default_in_carts

    @default_in_carts.setter
    def default_in_carts(self, value):
        self._default_in_carts = value
    @property
    def default_in_carts_detail(self):
        return self._default_in_carts_detail

    @default_in_carts_detail.setter
    def default_in_carts_detail(self, value):
        self._default_in_carts_detail = value
    @property
    def dish_cuisine(self):
        return self._dish_cuisine

    @dish_cuisine.setter
    def dish_cuisine(self, value):
        self._dish_cuisine = value
    @property
    def dish_detail_img_list(self):
        return self._dish_detail_img_list

    @dish_detail_img_list.setter
    def dish_detail_img_list(self, value):
        if isinstance(value, list):
            self._dish_detail_img_list = list()
            for i in value:
                self._dish_detail_img_list.append(i)
    @property
    def dish_id(self):
        return self._dish_id

    @dish_id.setter
    def dish_id(self, value):
        self._dish_id = value
    @property
    def dish_img(self):
        return self._dish_img

    @dish_img.setter
    def dish_img(self, value):
        self._dish_img = value
    @property
    def dish_name(self):
        return self._dish_name

    @dish_name.setter
    def dish_name(self, value):
        self._dish_name = value
    @property
    def dish_practice_list(self):
        return self._dish_practice_list

    @dish_practice_list.setter
    def dish_practice_list(self, value):
        if isinstance(value, list):
            self._dish_practice_list = list()
            for i in value:
                if isinstance(i, KbdishPracticeInfo):
                    self._dish_practice_list.append(i)
                else:
                    self._dish_practice_list.append(KbdishPracticeInfo.from_alipay_dict(i))
    @property
    def dish_sku_list(self):
        return self._dish_sku_list

    @dish_sku_list.setter
    def dish_sku_list(self, value):
        if isinstance(value, list):
            self._dish_sku_list = list()
            for i in value:
                if isinstance(i, KbdishSkuInfo):
                    self._dish_sku_list.append(i)
                else:
                    self._dish_sku_list.append(KbdishSkuInfo.from_alipay_dict(i))
    @property
    def dish_version(self):
        return self._dish_version

    @dish_version.setter
    def dish_version(self, value):
        self._dish_version = value
    @property
    def en_remember_code(self):
        return self._en_remember_code

    @en_remember_code.setter
    def en_remember_code(self, value):
        self._en_remember_code = value
    @property
    def ext_content(self):
        return self._ext_content

    @ext_content.setter
    def ext_content(self, value):
        self._ext_content = value
    @property
    def goods_id(self):
        return self._goods_id

    @goods_id.setter
    def goods_id(self, value):
        self._goods_id = value
    @property
    def material_binding_info_list(self):
        return self._material_binding_info_list

    @material_binding_info_list.setter
    def material_binding_info_list(self, value):
        if isinstance(value, list):
            self._material_binding_info_list = list()
            for i in value:
                if isinstance(i, KbdishMaterialBindingInfo):
                    self._material_binding_info_list.append(i)
                else:
                    self._material_binding_info_list.append(KbdishMaterialBindingInfo.from_alipay_dict(i))
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def min_serving(self):
        return self._min_serving

    @min_serving.setter
    def min_serving(self, value):
        self._min_serving = value
    @property
    def mini_add_num(self):
        return self._mini_add_num

    @mini_add_num.setter
    def mini_add_num(self, value):
        self._mini_add_num = value
    @property
    def nb_remember_code(self):
        return self._nb_remember_code

    @nb_remember_code.setter
    def nb_remember_code(self, value):
        self._nb_remember_code = value
    @property
    def not_count_threshold(self):
        return self._not_count_threshold

    @not_count_threshold.setter
    def not_count_threshold(self, value):
        self._not_count_threshold = value
    @property
    def out_dish_id(self):
        return self._out_dish_id

    @out_dish_id.setter
    def out_dish_id(self, value):
        self._out_dish_id = value
    @property
    def property_info_list(self):
        return self._property_info_list

    @property_info_list.setter
    def property_info_list(self, value):
        if isinstance(value, list):
            self._property_info_list = list()
            for i in value:
                if isinstance(i, KbdishPropertyInfo):
                    self._property_info_list.append(i)
                else:
                    self._property_info_list.append(KbdishPropertyInfo.from_alipay_dict(i))
    @property
    def remarks(self):
        return self._remarks

    @remarks.setter
    def remarks(self, value):
        self._remarks = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def tags(self):
        return self._tags

    @tags.setter
    def tags(self, value):
        self._tags = value
    @property
    def type_big(self):
        return self._type_big

    @type_big.setter
    def type_big(self, value):
        self._type_big = value
    @property
    def type_small(self):
        return self._type_small

    @type_small.setter
    def type_small(self, value):
        self._type_small = value
    @property
    def unit_id(self):
        return self._unit_id

    @unit_id.setter
    def unit_id(self, value):
        self._unit_id = value
    @property
    def update_user(self):
        return self._update_user

    @update_user.setter
    def update_user(self, value):
        self._update_user = value


    def to_alipay_dict(self):
        params = dict()
        if self.catetory_big_id:
            if hasattr(self.catetory_big_id, 'to_alipay_dict'):
                params['catetory_big_id'] = self.catetory_big_id.to_alipay_dict()
            else:
                params['catetory_big_id'] = self.catetory_big_id
        if self.catetory_small_id:
            if hasattr(self.catetory_small_id, 'to_alipay_dict'):
                params['catetory_small_id'] = self.catetory_small_id.to_alipay_dict()
            else:
                params['catetory_small_id'] = self.catetory_small_id
        if self.create_user:
            if hasattr(self.create_user, 'to_alipay_dict'):
                params['create_user'] = self.create_user.to_alipay_dict()
            else:
                params['create_user'] = self.create_user
        if self.cur_price_flag:
            if hasattr(self.cur_price_flag, 'to_alipay_dict'):
                params['cur_price_flag'] = self.cur_price_flag.to_alipay_dict()
            else:
                params['cur_price_flag'] = self.cur_price_flag
        if self.default_in_carts:
            if hasattr(self.default_in_carts, 'to_alipay_dict'):
                params['default_in_carts'] = self.default_in_carts.to_alipay_dict()
            else:
                params['default_in_carts'] = self.default_in_carts
        if self.default_in_carts_detail:
            if hasattr(self.default_in_carts_detail, 'to_alipay_dict'):
                params['default_in_carts_detail'] = self.default_in_carts_detail.to_alipay_dict()
            else:
                params['default_in_carts_detail'] = self.default_in_carts_detail
        if self.dish_cuisine:
            if hasattr(self.dish_cuisine, 'to_alipay_dict'):
                params['dish_cuisine'] = self.dish_cuisine.to_alipay_dict()
            else:
                params['dish_cuisine'] = self.dish_cuisine
        if self.dish_detail_img_list:
            if isinstance(self.dish_detail_img_list, list):
                for i in range(0, len(self.dish_detail_img_list)):
                    element = self.dish_detail_img_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.dish_detail_img_list[i] = element.to_alipay_dict()
            if hasattr(self.dish_detail_img_list, 'to_alipay_dict'):
                params['dish_detail_img_list'] = self.dish_detail_img_list.to_alipay_dict()
            else:
                params['dish_detail_img_list'] = self.dish_detail_img_list
        if self.dish_id:
            if hasattr(self.dish_id, 'to_alipay_dict'):
                params['dish_id'] = self.dish_id.to_alipay_dict()
            else:
                params['dish_id'] = self.dish_id
        if self.dish_img:
            if hasattr(self.dish_img, 'to_alipay_dict'):
                params['dish_img'] = self.dish_img.to_alipay_dict()
            else:
                params['dish_img'] = self.dish_img
        if self.dish_name:
            if hasattr(self.dish_name, 'to_alipay_dict'):
                params['dish_name'] = self.dish_name.to_alipay_dict()
            else:
                params['dish_name'] = self.dish_name
        if self.dish_practice_list:
            if isinstance(self.dish_practice_list, list):
                for i in range(0, len(self.dish_practice_list)):
                    element = self.dish_practice_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.dish_practice_list[i] = element.to_alipay_dict()
            if hasattr(self.dish_practice_list, 'to_alipay_dict'):
                params['dish_practice_list'] = self.dish_practice_list.to_alipay_dict()
            else:
                params['dish_practice_list'] = self.dish_practice_list
        if self.dish_sku_list:
            if isinstance(self.dish_sku_list, list):
                for i in range(0, len(self.dish_sku_list)):
                    element = self.dish_sku_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.dish_sku_list[i] = element.to_alipay_dict()
            if hasattr(self.dish_sku_list, 'to_alipay_dict'):
                params['dish_sku_list'] = self.dish_sku_list.to_alipay_dict()
            else:
                params['dish_sku_list'] = self.dish_sku_list
        if self.dish_version:
            if hasattr(self.dish_version, 'to_alipay_dict'):
                params['dish_version'] = self.dish_version.to_alipay_dict()
            else:
                params['dish_version'] = self.dish_version
        if self.en_remember_code:
            if hasattr(self.en_remember_code, 'to_alipay_dict'):
                params['en_remember_code'] = self.en_remember_code.to_alipay_dict()
            else:
                params['en_remember_code'] = self.en_remember_code
        if self.ext_content:
            if hasattr(self.ext_content, 'to_alipay_dict'):
                params['ext_content'] = self.ext_content.to_alipay_dict()
            else:
                params['ext_content'] = self.ext_content
        if self.goods_id:
            if hasattr(self.goods_id, 'to_alipay_dict'):
                params['goods_id'] = self.goods_id.to_alipay_dict()
            else:
                params['goods_id'] = self.goods_id
        if self.material_binding_info_list:
            if isinstance(self.material_binding_info_list, list):
                for i in range(0, len(self.material_binding_info_list)):
                    element = self.material_binding_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.material_binding_info_list[i] = element.to_alipay_dict()
            if hasattr(self.material_binding_info_list, 'to_alipay_dict'):
                params['material_binding_info_list'] = self.material_binding_info_list.to_alipay_dict()
            else:
                params['material_binding_info_list'] = self.material_binding_info_list
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.min_serving:
            if hasattr(self.min_serving, 'to_alipay_dict'):
                params['min_serving'] = self.min_serving.to_alipay_dict()
            else:
                params['min_serving'] = self.min_serving
        if self.mini_add_num:
            if hasattr(self.mini_add_num, 'to_alipay_dict'):
                params['mini_add_num'] = self.mini_add_num.to_alipay_dict()
            else:
                params['mini_add_num'] = self.mini_add_num
        if self.nb_remember_code:
            if hasattr(self.nb_remember_code, 'to_alipay_dict'):
                params['nb_remember_code'] = self.nb_remember_code.to_alipay_dict()
            else:
                params['nb_remember_code'] = self.nb_remember_code
        if self.not_count_threshold:
            if hasattr(self.not_count_threshold, 'to_alipay_dict'):
                params['not_count_threshold'] = self.not_count_threshold.to_alipay_dict()
            else:
                params['not_count_threshold'] = self.not_count_threshold
        if self.out_dish_id:
            if hasattr(self.out_dish_id, 'to_alipay_dict'):
                params['out_dish_id'] = self.out_dish_id.to_alipay_dict()
            else:
                params['out_dish_id'] = self.out_dish_id
        if self.property_info_list:
            if isinstance(self.property_info_list, list):
                for i in range(0, len(self.property_info_list)):
                    element = self.property_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.property_info_list[i] = element.to_alipay_dict()
            if hasattr(self.property_info_list, 'to_alipay_dict'):
                params['property_info_list'] = self.property_info_list.to_alipay_dict()
            else:
                params['property_info_list'] = self.property_info_list
        if self.remarks:
            if hasattr(self.remarks, 'to_alipay_dict'):
                params['remarks'] = self.remarks.to_alipay_dict()
            else:
                params['remarks'] = self.remarks
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.tags:
            if hasattr(self.tags, 'to_alipay_dict'):
                params['tags'] = self.tags.to_alipay_dict()
            else:
                params['tags'] = self.tags
        if self.type_big:
            if hasattr(self.type_big, 'to_alipay_dict'):
                params['type_big'] = self.type_big.to_alipay_dict()
            else:
                params['type_big'] = self.type_big
        if self.type_small:
            if hasattr(self.type_small, 'to_alipay_dict'):
                params['type_small'] = self.type_small.to_alipay_dict()
            else:
                params['type_small'] = self.type_small
        if self.unit_id:
            if hasattr(self.unit_id, 'to_alipay_dict'):
                params['unit_id'] = self.unit_id.to_alipay_dict()
            else:
                params['unit_id'] = self.unit_id
        if self.update_user:
            if hasattr(self.update_user, 'to_alipay_dict'):
                params['update_user'] = self.update_user.to_alipay_dict()
            else:
                params['update_user'] = self.update_user
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbdishInfo()
        if 'catetory_big_id' in d:
            o.catetory_big_id = d['catetory_big_id']
        if 'catetory_small_id' in d:
            o.catetory_small_id = d['catetory_small_id']
        if 'create_user' in d:
            o.create_user = d['create_user']
        if 'cur_price_flag' in d:
            o.cur_price_flag = d['cur_price_flag']
        if 'default_in_carts' in d:
            o.default_in_carts = d['default_in_carts']
        if 'default_in_carts_detail' in d:
            o.default_in_carts_detail = d['default_in_carts_detail']
        if 'dish_cuisine' in d:
            o.dish_cuisine = d['dish_cuisine']
        if 'dish_detail_img_list' in d:
            o.dish_detail_img_list = d['dish_detail_img_list']
        if 'dish_id' in d:
            o.dish_id = d['dish_id']
        if 'dish_img' in d:
            o.dish_img = d['dish_img']
        if 'dish_name' in d:
            o.dish_name = d['dish_name']
        if 'dish_practice_list' in d:
            o.dish_practice_list = d['dish_practice_list']
        if 'dish_sku_list' in d:
            o.dish_sku_list = d['dish_sku_list']
        if 'dish_version' in d:
            o.dish_version = d['dish_version']
        if 'en_remember_code' in d:
            o.en_remember_code = d['en_remember_code']
        if 'ext_content' in d:
            o.ext_content = d['ext_content']
        if 'goods_id' in d:
            o.goods_id = d['goods_id']
        if 'material_binding_info_list' in d:
            o.material_binding_info_list = d['material_binding_info_list']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'min_serving' in d:
            o.min_serving = d['min_serving']
        if 'mini_add_num' in d:
            o.mini_add_num = d['mini_add_num']
        if 'nb_remember_code' in d:
            o.nb_remember_code = d['nb_remember_code']
        if 'not_count_threshold' in d:
            o.not_count_threshold = d['not_count_threshold']
        if 'out_dish_id' in d:
            o.out_dish_id = d['out_dish_id']
        if 'property_info_list' in d:
            o.property_info_list = d['property_info_list']
        if 'remarks' in d:
            o.remarks = d['remarks']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'status' in d:
            o.status = d['status']
        if 'tags' in d:
            o.tags = d['tags']
        if 'type_big' in d:
            o.type_big = d['type_big']
        if 'type_small' in d:
            o.type_small = d['type_small']
        if 'unit_id' in d:
            o.unit_id = d['unit_id']
        if 'update_user' in d:
            o.update_user = d['update_user']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BkPosGoodsInfo import BkPosGoodsInfo


class MybankPaymentTradeOrderCreateModel(object):

    def __init__(self):
        self._currency_code = None
        self._ev_code = None
        self._goods_info = None
        self._out_trade_no = None
        self._partner_id = None
        self._pay_date = None
        self._pay_type = None
        self._pd_code = None
        self._recon_related_no = None
        self._remark = None
        self._seller_id = None
        self._total_amount = None

    @property
    def currency_code(self):
        return self._currency_code

    @currency_code.setter
    def currency_code(self, value):
        self._currency_code = value
    @property
    def ev_code(self):
        return self._ev_code

    @ev_code.setter
    def ev_code(self, value):
        self._ev_code = value
    @property
    def goods_info(self):
        return self._goods_info

    @goods_info.setter
    def goods_info(self, value):
        if isinstance(value, list):
            self._goods_info = list()
            for i in value:
                if isinstance(i, BkPosGoodsInfo):
                    self._goods_info.append(i)
                else:
                    self._goods_info.append(BkPosGoodsInfo.from_alipay_dict(i))
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def pay_date(self):
        return self._pay_date

    @pay_date.setter
    def pay_date(self, value):
        self._pay_date = value
    @property
    def pay_type(self):
        return self._pay_type

    @pay_type.setter
    def pay_type(self, value):
        self._pay_type = value
    @property
    def pd_code(self):
        return self._pd_code

    @pd_code.setter
    def pd_code(self, value):
        self._pd_code = value
    @property
    def recon_related_no(self):
        return self._recon_related_no

    @recon_related_no.setter
    def recon_related_no(self, value):
        self._recon_related_no = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.currency_code:
            if hasattr(self.currency_code, 'to_alipay_dict'):
                params['currency_code'] = self.currency_code.to_alipay_dict()
            else:
                params['currency_code'] = self.currency_code
        if self.ev_code:
            if hasattr(self.ev_code, 'to_alipay_dict'):
                params['ev_code'] = self.ev_code.to_alipay_dict()
            else:
                params['ev_code'] = self.ev_code
        if self.goods_info:
            if isinstance(self.goods_info, list):
                for i in range(0, len(self.goods_info)):
                    element = self.goods_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.goods_info[i] = element.to_alipay_dict()
            if hasattr(self.goods_info, 'to_alipay_dict'):
                params['goods_info'] = self.goods_info.to_alipay_dict()
            else:
                params['goods_info'] = self.goods_info
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.pay_date:
            if hasattr(self.pay_date, 'to_alipay_dict'):
                params['pay_date'] = self.pay_date.to_alipay_dict()
            else:
                params['pay_date'] = self.pay_date
        if self.pay_type:
            if hasattr(self.pay_type, 'to_alipay_dict'):
                params['pay_type'] = self.pay_type.to_alipay_dict()
            else:
                params['pay_type'] = self.pay_type
        if self.pd_code:
            if hasattr(self.pd_code, 'to_alipay_dict'):
                params['pd_code'] = self.pd_code.to_alipay_dict()
            else:
                params['pd_code'] = self.pd_code
        if self.recon_related_no:
            if hasattr(self.recon_related_no, 'to_alipay_dict'):
                params['recon_related_no'] = self.recon_related_no.to_alipay_dict()
            else:
                params['recon_related_no'] = self.recon_related_no
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankPaymentTradeOrderCreateModel()
        if 'currency_code' in d:
            o.currency_code = d['currency_code']
        if 'ev_code' in d:
            o.ev_code = d['ev_code']
        if 'goods_info' in d:
            o.goods_info = d['goods_info']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'pay_date' in d:
            o.pay_date = d['pay_date']
        if 'pay_type' in d:
            o.pay_type = d['pay_type']
        if 'pd_code' in d:
            o.pd_code = d['pd_code']
        if 'recon_related_no' in d:
            o.recon_related_no = d['recon_related_no']
        if 'remark' in d:
            o.remark = d['remark']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.VoucherUserExternalTradeInfo import VoucherUserExternalTradeInfo


class AlipayOfflineMarketingVoucherUseModel(object):

    def __init__(self):
        self._extend_params = None
        self._external_id = None
        self._external_trade_info = None
        self._external_voucher_code = None

    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        self._extend_params = value
    @property
    def external_id(self):
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        self._external_id = value
    @property
    def external_trade_info(self):
        return self._external_trade_info

    @external_trade_info.setter
    def external_trade_info(self, value):
        if isinstance(value, VoucherUserExternalTradeInfo):
            self._external_trade_info = value
        else:
            self._external_trade_info = VoucherUserExternalTradeInfo.from_alipay_dict(value)
    @property
    def external_voucher_code(self):
        return self._external_voucher_code

    @external_voucher_code.setter
    def external_voucher_code(self, value):
        self._external_voucher_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.extend_params:
            if hasattr(self.extend_params, 'to_alipay_dict'):
                params['extend_params'] = self.extend_params.to_alipay_dict()
            else:
                params['extend_params'] = self.extend_params
        if self.external_id:
            if hasattr(self.external_id, 'to_alipay_dict'):
                params['external_id'] = self.external_id.to_alipay_dict()
            else:
                params['external_id'] = self.external_id
        if self.external_trade_info:
            if hasattr(self.external_trade_info, 'to_alipay_dict'):
                params['external_trade_info'] = self.external_trade_info.to_alipay_dict()
            else:
                params['external_trade_info'] = self.external_trade_info
        if self.external_voucher_code:
            if hasattr(self.external_voucher_code, 'to_alipay_dict'):
                params['external_voucher_code'] = self.external_voucher_code.to_alipay_dict()
            else:
                params['external_voucher_code'] = self.external_voucher_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOfflineMarketingVoucherUseModel()
        if 'extend_params' in d:
            o.extend_params = d['extend_params']
        if 'external_id' in d:
            o.external_id = d['external_id']
        if 'external_trade_info' in d:
            o.external_trade_info = d['external_trade_info']
        if 'external_voucher_code' in d:
            o.external_voucher_code = d['external_voucher_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ReportDataItem import ReportDataItem


class KoubeiMarketingDataCustomreportQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingDataCustomreportQueryResponse, self).__init__()
        self._count = None
        self._report_data = None

    @property
    def count(self):
        return self._count

    @count.setter
    def count(self, value):
        self._count = value
    @property
    def report_data(self):
        return self._report_data

    @report_data.setter
    def report_data(self, value):
        if isinstance(value, list):
            self._report_data = list()
            for i in value:
                if isinstance(i, ReportDataItem):
                    self._report_data.append(i)
                else:
                    self._report_data.append(ReportDataItem.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingDataCustomreportQueryResponse, self).parse_response_content(response_content)
        if 'count' in response:
            self.count = response['count']
        if 'report_data' in response:
            self.report_data = response['report_data']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class KoubeiMerchantDepartmentModifyResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMerchantDepartmentModifyResponse, self).__init__()
        self._dept_id = None

    @property
    def dept_id(self):
        return self._dept_id

    @dept_id.setter
    def dept_id(self, value):
        self._dept_id = value

    def parse_response_content(self, response_content):
        response = super(KoubeiMerchantDepartmentModifyResponse, self).parse_response_content(response_content)
        if 'dept_id' in response:
            self.dept_id = response['dept_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundCouponWufuCardQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundCouponWufuCardQueryResponse, self).__init__()
        self._count = None

    @property
    def count(self):
        return self._count

    @count.setter
    def count(self, value):
        self._count = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundCouponWufuCardQueryResponse, self).parse_response_content(response_content)
        if 'count' in response:
            self.count = response['count']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceTransportEtcSettlementApplyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceTransportEtcSettlementApplyResponse, self).__init__()
        self._out_order_id = None
        self._pay_time = None
        self._total_amount = None
        self._trade_no = None
        self._trade_status = None
        self._trip_id = None

    @property
    def out_order_id(self):
        return self._out_order_id

    @out_order_id.setter
    def out_order_id(self, value):
        self._out_order_id = value
    @property
    def pay_time(self):
        return self._pay_time

    @pay_time.setter
    def pay_time(self, value):
        self._pay_time = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def trade_status(self):
        return self._trade_status

    @trade_status.setter
    def trade_status(self, value):
        self._trade_status = value
    @property
    def trip_id(self):
        return self._trip_id

    @trip_id.setter
    def trip_id(self, value):
        self._trip_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceTransportEtcSettlementApplyResponse, self).parse_response_content(response_content)
        if 'out_order_id' in response:
            self.out_order_id = response['out_order_id']
        if 'pay_time' in response:
            self.pay_time = response['pay_time']
        if 'total_amount' in response:
            self.total_amount = response['total_amount']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']
        if 'trade_status' in response:
            self.trade_status = response['trade_status']
        if 'trip_id' in response:
            self.trip_id = response['trip_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RiskRankInfoCode(object):

    def __init__(self):
        self._code = None
        self._contribution_degree = None
        self._desc = None
        self._model_name = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def contribution_degree(self):
        return self._contribution_degree

    @contribution_degree.setter
    def contribution_degree(self, value):
        self._contribution_degree = value
    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def model_name(self):
        return self._model_name

    @model_name.setter
    def model_name(self, value):
        self._model_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.contribution_degree:
            if hasattr(self.contribution_degree, 'to_alipay_dict'):
                params['contribution_degree'] = self.contribution_degree.to_alipay_dict()
            else:
                params['contribution_degree'] = self.contribution_degree
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.model_name:
            if hasattr(self.model_name, 'to_alipay_dict'):
                params['model_name'] = self.model_name.to_alipay_dict()
            else:
                params['model_name'] = self.model_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RiskRankInfoCode()
        if 'code' in d:
            o.code = d['code']
        if 'contribution_degree' in d:
            o.contribution_degree = d['contribution_degree']
        if 'desc' in d:
            o.desc = d['desc']
        if 'model_name' in d:
            o.model_name = d['model_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.RubbishDTO import RubbishDTO


class AlipayIserviceCognitiveClassificationCategorySyncModel(object):

    def __init__(self):
        self._biz_code = None
        self._city_code = None
        self._rubbish_list = None

    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def rubbish_list(self):
        return self._rubbish_list

    @rubbish_list.setter
    def rubbish_list(self, value):
        if isinstance(value, list):
            self._rubbish_list = list()
            for i in value:
                if isinstance(i, RubbishDTO):
                    self._rubbish_list.append(i)
                else:
                    self._rubbish_list.append(RubbishDTO.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.biz_code:
            if hasattr(self.biz_code, 'to_alipay_dict'):
                params['biz_code'] = self.biz_code.to_alipay_dict()
            else:
                params['biz_code'] = self.biz_code
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.rubbish_list:
            if isinstance(self.rubbish_list, list):
                for i in range(0, len(self.rubbish_list)):
                    element = self.rubbish_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.rubbish_list[i] = element.to_alipay_dict()
            if hasattr(self.rubbish_list, 'to_alipay_dict'):
                params['rubbish_list'] = self.rubbish_list.to_alipay_dict()
            else:
                params['rubbish_list'] = self.rubbish_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayIserviceCognitiveClassificationCategorySyncModel()
        if 'biz_code' in d:
            o.biz_code = d['biz_code']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'rubbish_list' in d:
            o.rubbish_list = d['rubbish_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPcreditLoanApplyCreateModel(object):

    def __init__(self):
        self._apply_amt = None
        self._cert_no = None
        self._name = None
        self._out_biz_no = None
        self._ratio = None
        self._scene = None

    @property
    def apply_amt(self):
        return self._apply_amt

    @apply_amt.setter
    def apply_amt(self, value):
        self._apply_amt = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def ratio(self):
        return self._ratio

    @ratio.setter
    def ratio(self, value):
        self._ratio = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_amt:
            if hasattr(self.apply_amt, 'to_alipay_dict'):
                params['apply_amt'] = self.apply_amt.to_alipay_dict()
            else:
                params['apply_amt'] = self.apply_amt
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.ratio:
            if hasattr(self.ratio, 'to_alipay_dict'):
                params['ratio'] = self.ratio.to_alipay_dict()
            else:
                params['ratio'] = self.ratio
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditLoanApplyCreateModel()
        if 'apply_amt' in d:
            o.apply_amt = d['apply_amt']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'name' in d:
            o.name = d['name']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'ratio' in d:
            o.ratio = d['ratio']
        if 'scene' in d:
            o.scene = d['scene']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.LabelContext import LabelContext


class Filter(object):

    def __init__(self):
        self._context = None
        self._template = None

    @property
    def context(self):
        return self._context

    @context.setter
    def context(self, value):
        if isinstance(value, LabelContext):
            self._context = value
        else:
            self._context = LabelContext.from_alipay_dict(value)
    @property
    def template(self):
        return self._template

    @template.setter
    def template(self, value):
        self._template = value


    def to_alipay_dict(self):
        params = dict()
        if self.context:
            if hasattr(self.context, 'to_alipay_dict'):
                params['context'] = self.context.to_alipay_dict()
            else:
                params['context'] = self.context
        if self.template:
            if hasattr(self.template, 'to_alipay_dict'):
                params['template'] = self.template.to_alipay_dict()
            else:
                params['template'] = self.template
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = Filter()
        if 'context' in d:
            o.context = d['context']
        if 'template' in d:
            o.template = d['template']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingCashticketTemplateModifyModel(object):

    def __init__(self):
        self._out_biz_no = None
        self._publish_end_time = None
        self._publish_start_time = None
        self._template_id = None
        self._ticket_valid_period = None

    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def publish_end_time(self):
        return self._publish_end_time

    @publish_end_time.setter
    def publish_end_time(self, value):
        self._publish_end_time = value
    @property
    def publish_start_time(self):
        return self._publish_start_time

    @publish_start_time.setter
    def publish_start_time(self, value):
        self._publish_start_time = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def ticket_valid_period(self):
        return self._ticket_valid_period

    @ticket_valid_period.setter
    def ticket_valid_period(self, value):
        self._ticket_valid_period = value


    def to_alipay_dict(self):
        params = dict()
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.publish_end_time:
            if hasattr(self.publish_end_time, 'to_alipay_dict'):
                params['publish_end_time'] = self.publish_end_time.to_alipay_dict()
            else:
                params['publish_end_time'] = self.publish_end_time
        if self.publish_start_time:
            if hasattr(self.publish_start_time, 'to_alipay_dict'):
                params['publish_start_time'] = self.publish_start_time.to_alipay_dict()
            else:
                params['publish_start_time'] = self.publish_start_time
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        if self.ticket_valid_period:
            if hasattr(self.ticket_valid_period, 'to_alipay_dict'):
                params['ticket_valid_period'] = self.ticket_valid_period.to_alipay_dict()
            else:
                params['ticket_valid_period'] = self.ticket_valid_period
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCashticketTemplateModifyModel()
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'publish_end_time' in d:
            o.publish_end_time = d['publish_end_time']
        if 'publish_start_time' in d:
            o.publish_start_time = d['publish_start_time']
        if 'template_id' in d:
            o.template_id = d['template_id']
        if 'ticket_valid_period' in d:
            o.ticket_valid_period = d['ticket_valid_period']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AliTrustAlipayCert(object):

    def __init__(self):
        self._birthday = None
        self._forward_url = None
        self._gender = None
        self._icon_url = None
        self._is_certified = None
        self._name = None

    @property
    def birthday(self):
        return self._birthday

    @birthday.setter
    def birthday(self, value):
        self._birthday = value
    @property
    def forward_url(self):
        return self._forward_url

    @forward_url.setter
    def forward_url(self, value):
        self._forward_url = value
    @property
    def gender(self):
        return self._gender

    @gender.setter
    def gender(self, value):
        self._gender = value
    @property
    def icon_url(self):
        return self._icon_url

    @icon_url.setter
    def icon_url(self, value):
        self._icon_url = value
    @property
    def is_certified(self):
        return self._is_certified

    @is_certified.setter
    def is_certified(self, value):
        self._is_certified = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value


    def to_alipay_dict(self):
        params = dict()
        if self.birthday:
            if hasattr(self.birthday, 'to_alipay_dict'):
                params['birthday'] = self.birthday.to_alipay_dict()
            else:
                params['birthday'] = self.birthday
        if self.forward_url:
            if hasattr(self.forward_url, 'to_alipay_dict'):
                params['forward_url'] = self.forward_url.to_alipay_dict()
            else:
                params['forward_url'] = self.forward_url
        if self.gender:
            if hasattr(self.gender, 'to_alipay_dict'):
                params['gender'] = self.gender.to_alipay_dict()
            else:
                params['gender'] = self.gender
        if self.icon_url:
            if hasattr(self.icon_url, 'to_alipay_dict'):
                params['icon_url'] = self.icon_url.to_alipay_dict()
            else:
                params['icon_url'] = self.icon_url
        if self.is_certified:
            if hasattr(self.is_certified, 'to_alipay_dict'):
                params['is_certified'] = self.is_certified.to_alipay_dict()
            else:
                params['is_certified'] = self.is_certified
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AliTrustAlipayCert()
        if 'birthday' in d:
            o.birthday = d['birthday']
        if 'forward_url' in d:
            o.forward_url = d['forward_url']
        if 'gender' in d:
            o.gender = d['gender']
        if 'icon_url' in d:
            o.icon_url = d['icon_url']
        if 'is_certified' in d:
            o.is_certified = d['is_certified']
        if 'name' in d:
            o.name = d['name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OriTxnInfo(object):

    def __init__(self):
        self._category_type = None
        self._category_value = None
        self._txn_info = None

    @property
    def category_type(self):
        return self._category_type

    @category_type.setter
    def category_type(self, value):
        self._category_type = value
    @property
    def category_value(self):
        return self._category_value

    @category_value.setter
    def category_value(self, value):
        self._category_value = value
    @property
    def txn_info(self):
        return self._txn_info

    @txn_info.setter
    def txn_info(self, value):
        self._txn_info = value


    def to_alipay_dict(self):
        params = dict()
        if self.category_type:
            if hasattr(self.category_type, 'to_alipay_dict'):
                params['category_type'] = self.category_type.to_alipay_dict()
            else:
                params['category_type'] = self.category_type
        if self.category_value:
            if hasattr(self.category_value, 'to_alipay_dict'):
                params['category_value'] = self.category_value.to_alipay_dict()
            else:
                params['category_value'] = self.category_value
        if self.txn_info:
            if hasattr(self.txn_info, 'to_alipay_dict'):
                params['txn_info'] = self.txn_info.to_alipay_dict()
            else:
                params['txn_info'] = self.txn_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OriTxnInfo()
        if 'category_type' in d:
            o.category_type = d['category_type']
        if 'category_value' in d:
            o.category_value = d['category_value']
        if 'txn_info' in d:
            o.txn_info = d['txn_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.FileItem import FileItem
from alipay.aop.api.constant.ParamConstants import *




class AlipaySecurityProdAfsrcVulCreateRequest(object):

    def __init__(self, biz_model=None):
        self._biz_model = biz_model
        self._business = None
        self._company = None
        self._detail = None
        self._hid = None
        self._level = None
        self._mobile_phone = None
        self._name = None
        self._nick = None
        self._status = None
        self._submit_time = None
        self._type_sub_first_id = None
        self._type_sub_first_name = None
        self._type_sub_second_id = None
        self._type_sub_second_name = None
        self._type_union_first_id = None
        self._type_union_second_id = None
        self._url = None
        self._user_id = None
        self._attachment = None
        self._version = "1.0"
        self._terminal_type = None
        self._terminal_info = None
        self._prod_code = None
        self._notify_url = None
        self._return_url = None
        self._udf_params = None
        self._need_encrypt = False

    @property
    def biz_model(self):
        return self._biz_model

    @biz_model.setter
    def biz_model(self, value):
        self._biz_model = value

    @property
    def business(self):
        return self._business

    @business.setter
    def business(self, value):
        self._business = value
    @property
    def company(self):
        return self._company

    @company.setter
    def company(self, value):
        self._company = value
    @property
    def detail(self):
        return self._detail

    @detail.setter
    def detail(self, value):
        self._detail = value
    @property
    def hid(self):
        return self._hid

    @hid.setter
    def hid(self, value):
        self._hid = value
    @property
    def level(self):
        return self._level

    @level.setter
    def level(self, value):
        self._level = value
    @property
    def mobile_phone(self):
        return self._mobile_phone

    @mobile_phone.setter
    def mobile_phone(self, value):
        self._mobile_phone = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def nick(self):
        return self._nick

    @nick.setter
    def nick(self, value):
        self._nick = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def submit_time(self):
        return self._submit_time

    @submit_time.setter
    def submit_time(self, value):
        self._submit_time = value
    @property
    def type_sub_first_id(self):
        return self._type_sub_first_id

    @type_sub_first_id.setter
    def type_sub_first_id(self, value):
        self._type_sub_first_id = value
    @property
    def type_sub_first_name(self):
        return self._type_sub_first_name

    @type_sub_first_name.setter
    def type_sub_first_name(self, value):
        self._type_sub_first_name = value
    @property
    def type_sub_second_id(self):
        return self._type_sub_second_id

    @type_sub_second_id.setter
    def type_sub_second_id(self, value):
        self._type_sub_second_id = value
    @property
    def type_sub_second_name(self):
        return self._type_sub_second_name

    @type_sub_second_name.setter
    def type_sub_second_name(self, value):
        self._type_sub_second_name = value
    @property
    def type_union_first_id(self):
        return self._type_union_first_id

    @type_union_first_id.setter
    def type_union_first_id(self, value):
        self._type_union_first_id = value
    @property
    def type_union_second_id(self):
        return self._type_union_second_id

    @type_union_second_id.setter
    def type_union_second_id(self, value):
        self._type_union_second_id = value
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    @property
    def attachment(self):
        return self._attachment

    @attachment.setter
    def attachment(self, value):
        if not isinstance(value, FileItem):
            return
        self._attachment = value

    @property
    def version(self):
        return self._version

    @version.setter
    def version(self, value):
        self._version = value

    @property
    def terminal_type(self):
        return self._terminal_type

    @terminal_type.setter
    def terminal_type(self, value):
        self._terminal_type = value

    @property
    def terminal_info(self):
        return self._terminal_info

    @terminal_info.setter
    def terminal_info(self, value):
        self._terminal_info = value

    @property
    def prod_code(self):
        return self._prod_code

    @prod_code.setter
    def prod_code(self, value):
        self._prod_code = value

    @property
    def notify_url(self):
        return self._notify_url

    @notify_url.setter
    def notify_url(self, value):
        self._notify_url = value

    @property
    def return_url(self):
        return self._return_url

    @return_url.setter
    def return_url(self, value):
        self._return_url = value

    @property
    def udf_params(self):
        return self._udf_params

    @udf_params.setter
    def udf_params(self, value):
        if not isinstance(value, dict):
            return
        self._udf_params = value

    @property
    def need_encrypt(self):
        return self._need_encrypt

    @need_encrypt.setter
    def need_encrypt(self, value):
        self._need_encrypt = value

    def add_other_text_param(self, key, value):
        if not self.udf_params:
            self.udf_params = dict()
        self.udf_params[key] = value

    def get_params(self):
        params = dict()
        params[P_METHOD] = 'alipay.security.prod.afsrc.vul.create'
        params[P_VERSION] = self.version
        if self.biz_model:
            params[P_BIZ_CONTENT] = json.dumps(obj=self.biz_model.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
        if self.business:
            if hasattr(self.business, 'to_alipay_dict'):
                params['business'] = json.dumps(obj=self.business.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['business'] = self.business
        if self.company:
            if hasattr(self.company, 'to_alipay_dict'):
                params['company'] = json.dumps(obj=self.company.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['company'] = self.company
        if self.detail:
            if hasattr(self.detail, 'to_alipay_dict'):
                params['detail'] = json.dumps(obj=self.detail.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['detail'] = self.detail
        if self.hid:
            if hasattr(self.hid, 'to_alipay_dict'):
                params['hid'] = json.dumps(obj=self.hid.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['hid'] = self.hid
        if self.level:
            if hasattr(self.level, 'to_alipay_dict'):
                params['level'] = json.dumps(obj=self.level.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['level'] = self.level
        if self.mobile_phone:
            if hasattr(self.mobile_phone, 'to_alipay_dict'):
                params['mobile_phone'] = json.dumps(obj=self.mobile_phone.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['mobile_phone'] = self.mobile_phone
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = json.dumps(obj=self.name.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['name'] = self.name
        if self.nick:
            if hasattr(self.nick, 'to_alipay_dict'):
                params['nick'] = json.dumps(obj=self.nick.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['nick'] = self.nick
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = json.dumps(obj=self.status.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['status'] = self.status
        if self.submit_time:
            if hasattr(self.submit_time, 'to_alipay_dict'):
                params['submit_time'] = json.dumps(obj=self.submit_time.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['submit_time'] = self.submit_time
        if self.type_sub_first_id:
            if hasattr(self.type_sub_first_id, 'to_alipay_dict'):
                params['type_sub_first_id'] = json.dumps(obj=self.type_sub_first_id.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['type_sub_first_id'] = self.type_sub_first_id
        if self.type_sub_first_name:
            if hasattr(self.type_sub_first_name, 'to_alipay_dict'):
                params['type_sub_first_name'] = json.dumps(obj=self.type_sub_first_name.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['type_sub_first_name'] = self.type_sub_first_name
        if self.type_sub_second_id:
            if hasattr(self.type_sub_second_id, 'to_alipay_dict'):
                params['type_sub_second_id'] = json.dumps(obj=self.type_sub_second_id.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['type_sub_second_id'] = self.type_sub_second_id
        if self.type_sub_second_name:
            if hasattr(self.type_sub_second_name, 'to_alipay_dict'):
                params['type_sub_second_name'] = json.dumps(obj=self.type_sub_second_name.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['type_sub_second_name'] = self.type_sub_second_name
        if self.type_union_first_id:
            if hasattr(self.type_union_first_id, 'to_alipay_dict'):
                params['type_union_first_id'] = json.dumps(obj=self.type_union_first_id.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['type_union_first_id'] = self.type_union_first_id
        if self.type_union_second_id:
            if hasattr(self.type_union_second_id, 'to_alipay_dict'):
                params['type_union_second_id'] = json.dumps(obj=self.type_union_second_id.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['type_union_second_id'] = self.type_union_second_id
        if self.url:
            if hasattr(self.url, 'to_alipay_dict'):
                params['url'] = json.dumps(obj=self.url.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['url'] = self.url
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = json.dumps(obj=self.user_id.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['user_id'] = self.user_id
        if self.terminal_type:
            params['terminal_type'] = self.terminal_type
        if self.terminal_info:
            params['terminal_info'] = self.terminal_info
        if self.prod_code:
            params['prod_code'] = self.prod_code
        if self.notify_url:
            params['notify_url'] = self.notify_url
        if self.return_url:
            params['return_url'] = self.return_url
        if self.udf_params:
            params.update(self.udf_params)
        return params

    def get_multipart_params(self):
        multipart_params = dict()
        if self.attachment:
            multipart_params['attachment'] = self.attachment
        return multipart_params



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SearchBoxServiceInfo import SearchBoxServiceInfo


class SearchBoxServiceModule(object):

    def __init__(self):
        self._module_id = None
        self._module_type = None
        self._service_infos = None

    @property
    def module_id(self):
        return self._module_id

    @module_id.setter
    def module_id(self, value):
        self._module_id = value
    @property
    def module_type(self):
        return self._module_type

    @module_type.setter
    def module_type(self, value):
        self._module_type = value
    @property
    def service_infos(self):
        return self._service_infos

    @service_infos.setter
    def service_infos(self, value):
        if isinstance(value, list):
            self._service_infos = list()
            for i in value:
                if isinstance(i, SearchBoxServiceInfo):
                    self._service_infos.append(i)
                else:
                    self._service_infos.append(SearchBoxServiceInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.module_id:
            if hasattr(self.module_id, 'to_alipay_dict'):
                params['module_id'] = self.module_id.to_alipay_dict()
            else:
                params['module_id'] = self.module_id
        if self.module_type:
            if hasattr(self.module_type, 'to_alipay_dict'):
                params['module_type'] = self.module_type.to_alipay_dict()
            else:
                params['module_type'] = self.module_type
        if self.service_infos:
            if isinstance(self.service_infos, list):
                for i in range(0, len(self.service_infos)):
                    element = self.service_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.service_infos[i] = element.to_alipay_dict()
            if hasattr(self.service_infos, 'to_alipay_dict'):
                params['service_infos'] = self.service_infos.to_alipay_dict()
            else:
                params['service_infos'] = self.service_infos
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SearchBoxServiceModule()
        if 'module_id' in d:
            o.module_id = d['module_id']
        if 'module_type' in d:
            o.module_type = d['module_type']
        if 'service_infos' in d:
            o.service_infos = d['service_infos']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayIserviceCognitiveOcrBankcardQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayIserviceCognitiveOcrBankcardQueryResponse, self).__init__()
        self._card_num = None
        self._request_id = None
        self._success = None
        self._trace_id = None

    @property
    def card_num(self):
        return self._card_num

    @card_num.setter
    def card_num(self, value):
        self._card_num = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayIserviceCognitiveOcrBankcardQueryResponse, self).parse_response_content(response_content)
        if 'card_num' in response:
            self.card_num = response['card_num']
        if 'request_id' in response:
            self.request_id = response['request_id']
        if 'success' in response:
            self.success = response['success']
        if 'trace_id' in response:
            self.trace_id = response['trace_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundFlexiblestaffingAuthorizeInitializeResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundFlexiblestaffingAuthorizeInitializeResponse, self).__init__()
        self._biz_scene = None
        self._initialize_code = None
        self._initialize_code_type = None
        self._out_biz_no = None
        self._product_code = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def initialize_code(self):
        return self._initialize_code

    @initialize_code.setter
    def initialize_code(self, value):
        self._initialize_code = value
    @property
    def initialize_code_type(self):
        return self._initialize_code_type

    @initialize_code_type.setter
    def initialize_code_type(self, value):
        self._initialize_code_type = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundFlexiblestaffingAuthorizeInitializeResponse, self).parse_response_content(response_content)
        if 'biz_scene' in response:
            self.biz_scene = response['biz_scene']
        if 'initialize_code' in response:
            self.initialize_code = response['initialize_code']
        if 'initialize_code_type' in response:
            self.initialize_code_type = response['initialize_code_type']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'product_code' in response:
            self.product_code = response['product_code']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GoodsSafetyInventory import GoodsSafetyInventory


class KoubeiRetailWmsGoodssafetyinventoryModifyModel(object):

    def __init__(self):
        self._goods_safety_inventorys = None

    @property
    def goods_safety_inventorys(self):
        return self._goods_safety_inventorys

    @goods_safety_inventorys.setter
    def goods_safety_inventorys(self, value):
        if isinstance(value, list):
            self._goods_safety_inventorys = list()
            for i in value:
                if isinstance(i, GoodsSafetyInventory):
                    self._goods_safety_inventorys.append(i)
                else:
                    self._goods_safety_inventorys.append(GoodsSafetyInventory.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.goods_safety_inventorys:
            if isinstance(self.goods_safety_inventorys, list):
                for i in range(0, len(self.goods_safety_inventorys)):
                    element = self.goods_safety_inventorys[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.goods_safety_inventorys[i] = element.to_alipay_dict()
            if hasattr(self.goods_safety_inventorys, 'to_alipay_dict'):
                params['goods_safety_inventorys'] = self.goods_safety_inventorys.to_alipay_dict()
            else:
                params['goods_safety_inventorys'] = self.goods_safety_inventorys
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiRetailWmsGoodssafetyinventoryModifyModel()
        if 'goods_safety_inventorys' in d:
            o.goods_safety_inventorys = d['goods_safety_inventorys']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.JobWorthPositionInfo import JobWorthPositionInfo


class ZhimaCustomerJobworthPositionAddModel(object):

    def __init__(self):
        self._jobworth_position_info = None

    @property
    def jobworth_position_info(self):
        return self._jobworth_position_info

    @jobworth_position_info.setter
    def jobworth_position_info(self, value):
        if isinstance(value, JobWorthPositionInfo):
            self._jobworth_position_info = value
        else:
            self._jobworth_position_info = JobWorthPositionInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.jobworth_position_info:
            if hasattr(self.jobworth_position_info, 'to_alipay_dict'):
                params['jobworth_position_info'] = self.jobworth_position_info.to_alipay_dict()
            else:
                params['jobworth_position_info'] = self.jobworth_position_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCustomerJobworthPositionAddModel()
        if 'jobworth_position_info' in d:
            o.jobworth_position_info = d['jobworth_position_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechDataServiceBlockchainContractQueryModel(object):

    def __init__(self):
        self._at_tenant_name = None
        self._block_chain_id = None
        self._block_hash = None
        self._contract_hash = None
        self._end_timestamp = None
        self._page_no = None
        self._page_size = None
        self._start_timestamp = None

    @property
    def at_tenant_name(self):
        return self._at_tenant_name

    @at_tenant_name.setter
    def at_tenant_name(self, value):
        self._at_tenant_name = value
    @property
    def block_chain_id(self):
        return self._block_chain_id

    @block_chain_id.setter
    def block_chain_id(self, value):
        self._block_chain_id = value
    @property
    def block_hash(self):
        return self._block_hash

    @block_hash.setter
    def block_hash(self, value):
        self._block_hash = value
    @property
    def contract_hash(self):
        return self._contract_hash

    @contract_hash.setter
    def contract_hash(self, value):
        self._contract_hash = value
    @property
    def end_timestamp(self):
        return self._end_timestamp

    @end_timestamp.setter
    def end_timestamp(self, value):
        self._end_timestamp = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def start_timestamp(self):
        return self._start_timestamp

    @start_timestamp.setter
    def start_timestamp(self, value):
        self._start_timestamp = value


    def to_alipay_dict(self):
        params = dict()
        if self.at_tenant_name:
            if hasattr(self.at_tenant_name, 'to_alipay_dict'):
                params['at_tenant_name'] = self.at_tenant_name.to_alipay_dict()
            else:
                params['at_tenant_name'] = self.at_tenant_name
        if self.block_chain_id:
            if hasattr(self.block_chain_id, 'to_alipay_dict'):
                params['block_chain_id'] = self.block_chain_id.to_alipay_dict()
            else:
                params['block_chain_id'] = self.block_chain_id
        if self.block_hash:
            if hasattr(self.block_hash, 'to_alipay_dict'):
                params['block_hash'] = self.block_hash.to_alipay_dict()
            else:
                params['block_hash'] = self.block_hash
        if self.contract_hash:
            if hasattr(self.contract_hash, 'to_alipay_dict'):
                params['contract_hash'] = self.contract_hash.to_alipay_dict()
            else:
                params['contract_hash'] = self.contract_hash
        if self.end_timestamp:
            if hasattr(self.end_timestamp, 'to_alipay_dict'):
                params['end_timestamp'] = self.end_timestamp.to_alipay_dict()
            else:
                params['end_timestamp'] = self.end_timestamp
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.start_timestamp:
            if hasattr(self.start_timestamp, 'to_alipay_dict'):
                params['start_timestamp'] = self.start_timestamp.to_alipay_dict()
            else:
                params['start_timestamp'] = self.start_timestamp
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechDataServiceBlockchainContractQueryModel()
        if 'at_tenant_name' in d:
            o.at_tenant_name = d['at_tenant_name']
        if 'block_chain_id' in d:
            o.block_chain_id = d['block_chain_id']
        if 'block_hash' in d:
            o.block_hash = d['block_hash']
        if 'contract_hash' in d:
            o.contract_hash = d['contract_hash']
        if 'end_timestamp' in d:
            o.end_timestamp = d['end_timestamp']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'start_timestamp' in d:
            o.start_timestamp = d['start_timestamp']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CommerceMedicalBankcardCertificationQueryData import CommerceMedicalBankcardCertificationQueryData


class AlipayCommerceMedicalBankcardCertificationQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceMedicalBankcardCertificationQueryResponse, self).__init__()
        self._data = None
        self._error_message = None
        self._result_code = None

    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        if isinstance(value, CommerceMedicalBankcardCertificationQueryData):
            self._data = value
        else:
            self._data = CommerceMedicalBankcardCertificationQueryData.from_alipay_dict(value)
    @property
    def error_message(self):
        return self._error_message

    @error_message.setter
    def error_message(self, value):
        self._error_message = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceMedicalBankcardCertificationQueryResponse, self).parse_response_content(response_content)
        if 'data' in response:
            self.data = response['data']
        if 'error_message' in response:
            self.error_message = response['error_message']
        if 'result_code' in response:
            self.result_code = response['result_code']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OrderVoucherAvailableCityCode(object):

    def __init__(self):
        self._all_city = None
        self._city_codes = None

    @property
    def all_city(self):
        return self._all_city

    @all_city.setter
    def all_city(self, value):
        self._all_city = value
    @property
    def city_codes(self):
        return self._city_codes

    @city_codes.setter
    def city_codes(self, value):
        if isinstance(value, list):
            self._city_codes = list()
            for i in value:
                self._city_codes.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.all_city:
            if hasattr(self.all_city, 'to_alipay_dict'):
                params['all_city'] = self.all_city.to_alipay_dict()
            else:
                params['all_city'] = self.all_city
        if self.city_codes:
            if isinstance(self.city_codes, list):
                for i in range(0, len(self.city_codes)):
                    element = self.city_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.city_codes[i] = element.to_alipay_dict()
            if hasattr(self.city_codes, 'to_alipay_dict'):
                params['city_codes'] = self.city_codes.to_alipay_dict()
            else:
                params['city_codes'] = self.city_codes
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OrderVoucherAvailableCityCode()
        if 'all_city' in d:
            o.all_city = d['all_city']
        if 'city_codes' in d:
            o.city_codes = d['city_codes']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CrowdSummary(object):

    def __init__(self):
        self._crowd_count = None
        self._crowd_id = None
        self._crowd_name = None
        self._status = None

    @property
    def crowd_count(self):
        return self._crowd_count

    @crowd_count.setter
    def crowd_count(self, value):
        self._crowd_count = value
    @property
    def crowd_id(self):
        return self._crowd_id

    @crowd_id.setter
    def crowd_id(self, value):
        self._crowd_id = value
    @property
    def crowd_name(self):
        return self._crowd_name

    @crowd_name.setter
    def crowd_name(self, value):
        self._crowd_name = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.crowd_count:
            if hasattr(self.crowd_count, 'to_alipay_dict'):
                params['crowd_count'] = self.crowd_count.to_alipay_dict()
            else:
                params['crowd_count'] = self.crowd_count
        if self.crowd_id:
            if hasattr(self.crowd_id, 'to_alipay_dict'):
                params['crowd_id'] = self.crowd_id.to_alipay_dict()
            else:
                params['crowd_id'] = self.crowd_id
        if self.crowd_name:
            if hasattr(self.crowd_name, 'to_alipay_dict'):
                params['crowd_name'] = self.crowd_name.to_alipay_dict()
            else:
                params['crowd_name'] = self.crowd_name
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CrowdSummary()
        if 'crowd_count' in d:
            o.crowd_count = d['crowd_count']
        if 'crowd_id' in d:
            o.crowd_id = d['crowd_id']
        if 'crowd_name' in d:
            o.crowd_name = d['crowd_name']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TextContent(object):

    def __init__(self):
        self._content = None
        self._title = None

    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TextContent()
        if 'content' in d:
            o.content = d['content']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class KoubeiSalesLeadsShopleadsCreateResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiSalesLeadsShopleadsCreateResponse, self).__init__()
        self._leads_id = None

    @property
    def leads_id(self):
        return self._leads_id

    @leads_id.setter
    def leads_id(self, value):
        self._leads_id = value

    def parse_response_content(self, response_content):
        response = super(KoubeiSalesLeadsShopleadsCreateResponse, self).parse_response_content(response_content)
        if 'leads_id' in response:
            self.leads_id = response['leads_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SubVenueAuditStatus import SubVenueAuditStatus


class AlipayCommerceSportsVenueSimpleCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceSportsVenueSimpleCreateResponse, self).__init__()
        self._desc = None
        self._out_venue_id = None
        self._sub_venue_list = None
        self._venue_id = None
        self._venue_status = None

    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def out_venue_id(self):
        return self._out_venue_id

    @out_venue_id.setter
    def out_venue_id(self, value):
        self._out_venue_id = value
    @property
    def sub_venue_list(self):
        return self._sub_venue_list

    @sub_venue_list.setter
    def sub_venue_list(self, value):
        if isinstance(value, list):
            self._sub_venue_list = list()
            for i in value:
                if isinstance(i, SubVenueAuditStatus):
                    self._sub_venue_list.append(i)
                else:
                    self._sub_venue_list.append(SubVenueAuditStatus.from_alipay_dict(i))
    @property
    def venue_id(self):
        return self._venue_id

    @venue_id.setter
    def venue_id(self, value):
        self._venue_id = value
    @property
    def venue_status(self):
        return self._venue_status

    @venue_status.setter
    def venue_status(self, value):
        self._venue_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceSportsVenueSimpleCreateResponse, self).parse_response_content(response_content)
        if 'desc' in response:
            self.desc = response['desc']
        if 'out_venue_id' in response:
            self.out_venue_id = response['out_venue_id']
        if 'sub_venue_list' in response:
            self.sub_venue_list = response['sub_venue_list']
        if 'venue_id' in response:
            self.venue_id = response['venue_id']
        if 'venue_status' in response:
            self.venue_status = response['venue_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.OfflinepayErrorIndicator import OfflinepayErrorIndicator


class OfflinepayBaseRPCResponseInfo(object):

    def __init__(self):
        self._error_indicator = None
        self._ext_info = None
        self._success = None
        self._time = None

    @property
    def error_indicator(self):
        return self._error_indicator

    @error_indicator.setter
    def error_indicator(self, value):
        if isinstance(value, OfflinepayErrorIndicator):
            self._error_indicator = value
        else:
            self._error_indicator = OfflinepayErrorIndicator.from_alipay_dict(value)
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value
    @property
    def time(self):
        return self._time

    @time.setter
    def time(self, value):
        self._time = value


    def to_alipay_dict(self):
        params = dict()
        if self.error_indicator:
            if hasattr(self.error_indicator, 'to_alipay_dict'):
                params['error_indicator'] = self.error_indicator.to_alipay_dict()
            else:
                params['error_indicator'] = self.error_indicator
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.success:
            if hasattr(self.success, 'to_alipay_dict'):
                params['success'] = self.success.to_alipay_dict()
            else:
                params['success'] = self.success
        if self.time:
            if hasattr(self.time, 'to_alipay_dict'):
                params['time'] = self.time.to_alipay_dict()
            else:
                params['time'] = self.time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OfflinepayBaseRPCResponseInfo()
        if 'error_indicator' in d:
            o.error_indicator = d['error_indicator']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'success' in d:
            o.success = d['success']
        if 'time' in d:
            o.time = d['time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEducateCampusBiztaskFinishModel(object):

    def __init__(self):
        self._channel_code = None
        self._task_bonus = None
        self._task_id = None
        self._task_type = None
        self._user_id = None

    @property
    def channel_code(self):
        return self._channel_code

    @channel_code.setter
    def channel_code(self, value):
        self._channel_code = value
    @property
    def task_bonus(self):
        return self._task_bonus

    @task_bonus.setter
    def task_bonus(self, value):
        self._task_bonus = value
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value
    @property
    def task_type(self):
        return self._task_type

    @task_type.setter
    def task_type(self, value):
        self._task_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.channel_code:
            if hasattr(self.channel_code, 'to_alipay_dict'):
                params['channel_code'] = self.channel_code.to_alipay_dict()
            else:
                params['channel_code'] = self.channel_code
        if self.task_bonus:
            if hasattr(self.task_bonus, 'to_alipay_dict'):
                params['task_bonus'] = self.task_bonus.to_alipay_dict()
            else:
                params['task_bonus'] = self.task_bonus
        if self.task_id:
            if hasattr(self.task_id, 'to_alipay_dict'):
                params['task_id'] = self.task_id.to_alipay_dict()
            else:
                params['task_id'] = self.task_id
        if self.task_type:
            if hasattr(self.task_type, 'to_alipay_dict'):
                params['task_type'] = self.task_type.to_alipay_dict()
            else:
                params['task_type'] = self.task_type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateCampusBiztaskFinishModel()
        if 'channel_code' in d:
            o.channel_code = d['channel_code']
        if 'task_bonus' in d:
            o.task_bonus = d['task_bonus']
        if 'task_id' in d:
            o.task_id = d['task_id']
        if 'task_type' in d:
            o.task_type = d['task_type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOverseasRemitBeneficialinfoQueryModel(object):

    def __init__(self):
        self._base_currency = None
        self._exchange_rate = None
        self._extend_info = None
        self._logon_id = None
        self._out_biz_no = None
        self._receive_amount = None
        self._receive_currency = None
        self._receiver_first_name = None
        self._receiver_full_name = None
        self._receiver_last_name = None
        self._receiver_mid = None
        self._receiver_middle_name = None
        self._remit_purpose = None
        self._send_amount = None
        self._send_country = None
        self._send_currency = None
        self._sender_mid = None
        self._sender_name = None
        self._sender_nationality = None

    @property
    def base_currency(self):
        return self._base_currency

    @base_currency.setter
    def base_currency(self, value):
        self._base_currency = value
    @property
    def exchange_rate(self):
        return self._exchange_rate

    @exchange_rate.setter
    def exchange_rate(self, value):
        self._exchange_rate = value
    @property
    def extend_info(self):
        return self._extend_info

    @extend_info.setter
    def extend_info(self, value):
        self._extend_info = value
    @property
    def logon_id(self):
        return self._logon_id

    @logon_id.setter
    def logon_id(self, value):
        self._logon_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def receive_amount(self):
        return self._receive_amount

    @receive_amount.setter
    def receive_amount(self, value):
        self._receive_amount = value
    @property
    def receive_currency(self):
        return self._receive_currency

    @receive_currency.setter
    def receive_currency(self, value):
        self._receive_currency = value
    @property
    def receiver_first_name(self):
        return self._receiver_first_name

    @receiver_first_name.setter
    def receiver_first_name(self, value):
        self._receiver_first_name = value
    @property
    def receiver_full_name(self):
        return self._receiver_full_name

    @receiver_full_name.setter
    def receiver_full_name(self, value):
        self._receiver_full_name = value
    @property
    def receiver_last_name(self):
        return self._receiver_last_name

    @receiver_last_name.setter
    def receiver_last_name(self, value):
        self._receiver_last_name = value
    @property
    def receiver_mid(self):
        return self._receiver_mid

    @receiver_mid.setter
    def receiver_mid(self, value):
        self._receiver_mid = value
    @property
    def receiver_middle_name(self):
        return self._receiver_middle_name

    @receiver_middle_name.setter
    def receiver_middle_name(self, value):
        self._receiver_middle_name = value
    @property
    def remit_purpose(self):
        return self._remit_purpose

    @remit_purpose.setter
    def remit_purpose(self, value):
        self._remit_purpose = value
    @property
    def send_amount(self):
        return self._send_amount

    @send_amount.setter
    def send_amount(self, value):
        self._send_amount = value
    @property
    def send_country(self):
        return self._send_country

    @send_country.setter
    def send_country(self, value):
        self._send_country = value
    @property
    def send_currency(self):
        return self._send_currency

    @send_currency.setter
    def send_currency(self, value):
        self._send_currency = value
    @property
    def sender_mid(self):
        return self._sender_mid

    @sender_mid.setter
    def sender_mid(self, value):
        self._sender_mid = value
    @property
    def sender_name(self):
        return self._sender_name

    @sender_name.setter
    def sender_name(self, value):
        self._sender_name = value
    @property
    def sender_nationality(self):
        return self._sender_nationality

    @sender_nationality.setter
    def sender_nationality(self, value):
        self._sender_nationality = value


    def to_alipay_dict(self):
        params = dict()
        if self.base_currency:
            if hasattr(self.base_currency, 'to_alipay_dict'):
                params['base_currency'] = self.base_currency.to_alipay_dict()
            else:
                params['base_currency'] = self.base_currency
        if self.exchange_rate:
            if hasattr(self.exchange_rate, 'to_alipay_dict'):
                params['exchange_rate'] = self.exchange_rate.to_alipay_dict()
            else:
                params['exchange_rate'] = self.exchange_rate
        if self.extend_info:
            if hasattr(self.extend_info, 'to_alipay_dict'):
                params['extend_info'] = self.extend_info.to_alipay_dict()
            else:
                params['extend_info'] = self.extend_info
        if self.logon_id:
            if hasattr(self.logon_id, 'to_alipay_dict'):
                params['logon_id'] = self.logon_id.to_alipay_dict()
            else:
                params['logon_id'] = self.logon_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.receive_amount:
            if hasattr(self.receive_amount, 'to_alipay_dict'):
                params['receive_amount'] = self.receive_amount.to_alipay_dict()
            else:
                params['receive_amount'] = self.receive_amount
        if self.receive_currency:
            if hasattr(self.receive_currency, 'to_alipay_dict'):
                params['receive_currency'] = self.receive_currency.to_alipay_dict()
            else:
                params['receive_currency'] = self.receive_currency
        if self.receiver_first_name:
            if hasattr(self.receiver_first_name, 'to_alipay_dict'):
                params['receiver_first_name'] = self.receiver_first_name.to_alipay_dict()
            else:
                params['receiver_first_name'] = self.receiver_first_name
        if self.receiver_full_name:
            if hasattr(self.receiver_full_name, 'to_alipay_dict'):
                params['receiver_full_name'] = self.receiver_full_name.to_alipay_dict()
            else:
                params['receiver_full_name'] = self.receiver_full_name
        if self.receiver_last_name:
            if hasattr(self.receiver_last_name, 'to_alipay_dict'):
                params['receiver_last_name'] = self.receiver_last_name.to_alipay_dict()
            else:
                params['receiver_last_name'] = self.receiver_last_name
        if self.receiver_mid:
            if hasattr(self.receiver_mid, 'to_alipay_dict'):
                params['receiver_mid'] = self.receiver_mid.to_alipay_dict()
            else:
                params['receiver_mid'] = self.receiver_mid
        if self.receiver_middle_name:
            if hasattr(self.receiver_middle_name, 'to_alipay_dict'):
                params['receiver_middle_name'] = self.receiver_middle_name.to_alipay_dict()
            else:
                params['receiver_middle_name'] = self.receiver_middle_name
        if self.remit_purpose:
            if hasattr(self.remit_purpose, 'to_alipay_dict'):
                params['remit_purpose'] = self.remit_purpose.to_alipay_dict()
            else:
                params['remit_purpose'] = self.remit_purpose
        if self.send_amount:
            if hasattr(self.send_amount, 'to_alipay_dict'):
                params['send_amount'] = self.send_amount.to_alipay_dict()
            else:
                params['send_amount'] = self.send_amount
        if self.send_country:
            if hasattr(self.send_country, 'to_alipay_dict'):
                params['send_country'] = self.send_country.to_alipay_dict()
            else:
                params['send_country'] = self.send_country
        if self.send_currency:
            if hasattr(self.send_currency, 'to_alipay_dict'):
                params['send_currency'] = self.send_currency.to_alipay_dict()
            else:
                params['send_currency'] = self.send_currency
        if self.sender_mid:
            if hasattr(self.sender_mid, 'to_alipay_dict'):
                params['sender_mid'] = self.sender_mid.to_alipay_dict()
            else:
                params['sender_mid'] = self.sender_mid
        if self.sender_name:
            if hasattr(self.sender_name, 'to_alipay_dict'):
                params['sender_name'] = self.sender_name.to_alipay_dict()
            else:
                params['sender_name'] = self.sender_name
        if self.sender_nationality:
            if hasattr(self.sender_nationality, 'to_alipay_dict'):
                params['sender_nationality'] = self.sender_nationality.to_alipay_dict()
            else:
                params['sender_nationality'] = self.sender_nationality
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOverseasRemitBeneficialinfoQueryModel()
        if 'base_currency' in d:
            o.base_currency = d['base_currency']
        if 'exchange_rate' in d:
            o.exchange_rate = d['exchange_rate']
        if 'extend_info' in d:
            o.extend_info = d['extend_info']
        if 'logon_id' in d:
            o.logon_id = d['logon_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'receive_amount' in d:
            o.receive_amount = d['receive_amount']
        if 'receive_currency' in d:
            o.receive_currency = d['receive_currency']
        if 'receiver_first_name' in d:
            o.receiver_first_name = d['receiver_first_name']
        if 'receiver_full_name' in d:
            o.receiver_full_name = d['receiver_full_name']
        if 'receiver_last_name' in d:
            o.receiver_last_name = d['receiver_last_name']
        if 'receiver_mid' in d:
            o.receiver_mid = d['receiver_mid']
        if 'receiver_middle_name' in d:
            o.receiver_middle_name = d['receiver_middle_name']
        if 'remit_purpose' in d:
            o.remit_purpose = d['remit_purpose']
        if 'send_amount' in d:
            o.send_amount = d['send_amount']
        if 'send_country' in d:
            o.send_country = d['send_country']
        if 'send_currency' in d:
            o.send_currency = d['send_currency']
        if 'sender_mid' in d:
            o.sender_mid = d['sender_mid']
        if 'sender_name' in d:
            o.sender_name = d['sender_name']
        if 'sender_nationality' in d:
            o.sender_nationality = d['sender_nationality']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SignResultValue(object):

    def __init__(self):
        self._effect_biz_value = None

    @property
    def effect_biz_value(self):
        return self._effect_biz_value

    @effect_biz_value.setter
    def effect_biz_value(self, value):
        self._effect_biz_value = value


    def to_alipay_dict(self):
        params = dict()
        if self.effect_biz_value:
            if hasattr(self.effect_biz_value, 'to_alipay_dict'):
                params['effect_biz_value'] = self.effect_biz_value.to_alipay_dict()
            else:
                params['effect_biz_value'] = self.effect_biz_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SignResultValue()
        if 'effect_biz_value' in d:
            o.effect_biz_value = d['effect_biz_value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class UseRuleInfo(object):

    def __init__(self):
        self._suitable_shops = None
        self._use_mode = None

    @property
    def suitable_shops(self):
        return self._suitable_shops

    @suitable_shops.setter
    def suitable_shops(self, value):
        if isinstance(value, list):
            self._suitable_shops = list()
            for i in value:
                self._suitable_shops.append(i)
    @property
    def use_mode(self):
        return self._use_mode

    @use_mode.setter
    def use_mode(self, value):
        if isinstance(value, list):
            self._use_mode = list()
            for i in value:
                self._use_mode.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.suitable_shops:
            if isinstance(self.suitable_shops, list):
                for i in range(0, len(self.suitable_shops)):
                    element = self.suitable_shops[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.suitable_shops[i] = element.to_alipay_dict()
            if hasattr(self.suitable_shops, 'to_alipay_dict'):
                params['suitable_shops'] = self.suitable_shops.to_alipay_dict()
            else:
                params['suitable_shops'] = self.suitable_shops
        if self.use_mode:
            if isinstance(self.use_mode, list):
                for i in range(0, len(self.use_mode)):
                    element = self.use_mode[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.use_mode[i] = element.to_alipay_dict()
            if hasattr(self.use_mode, 'to_alipay_dict'):
                params['use_mode'] = self.use_mode.to_alipay_dict()
            else:
                params['use_mode'] = self.use_mode
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = UseRuleInfo()
        if 'suitable_shops' in d:
            o.suitable_shops = d['suitable_shops']
        if 'use_mode' in d:
            o.use_mode = d['use_mode']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.VehicleConditionInfo import VehicleConditionInfo
from alipay.aop.api.domain.VehicleModuleInfo import VehicleModuleInfo


class VehicleMessageInfo(object):

    def __init__(self):
        self._vehicle_cond_infos = None
        self._vehicle_module_infos = None

    @property
    def vehicle_cond_infos(self):
        return self._vehicle_cond_infos

    @vehicle_cond_infos.setter
    def vehicle_cond_infos(self, value):
        if isinstance(value, list):
            self._vehicle_cond_infos = list()
            for i in value:
                if isinstance(i, VehicleConditionInfo):
                    self._vehicle_cond_infos.append(i)
                else:
                    self._vehicle_cond_infos.append(VehicleConditionInfo.from_alipay_dict(i))
    @property
    def vehicle_module_infos(self):
        return self._vehicle_module_infos

    @vehicle_module_infos.setter
    def vehicle_module_infos(self, value):
        if isinstance(value, list):
            self._vehicle_module_infos = list()
            for i in value:
                if isinstance(i, VehicleModuleInfo):
                    self._vehicle_module_infos.append(i)
                else:
                    self._vehicle_module_infos.append(VehicleModuleInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.vehicle_cond_infos:
            if isinstance(self.vehicle_cond_infos, list):
                for i in range(0, len(self.vehicle_cond_infos)):
                    element = self.vehicle_cond_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.vehicle_cond_infos[i] = element.to_alipay_dict()
            if hasattr(self.vehicle_cond_infos, 'to_alipay_dict'):
                params['vehicle_cond_infos'] = self.vehicle_cond_infos.to_alipay_dict()
            else:
                params['vehicle_cond_infos'] = self.vehicle_cond_infos
        if self.vehicle_module_infos:
            if isinstance(self.vehicle_module_infos, list):
                for i in range(0, len(self.vehicle_module_infos)):
                    element = self.vehicle_module_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.vehicle_module_infos[i] = element.to_alipay_dict()
            if hasattr(self.vehicle_module_infos, 'to_alipay_dict'):
                params['vehicle_module_infos'] = self.vehicle_module_infos.to_alipay_dict()
            else:
                params['vehicle_module_infos'] = self.vehicle_module_infos
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VehicleMessageInfo()
        if 'vehicle_cond_infos' in d:
            o.vehicle_cond_infos = d['vehicle_cond_infos']
        if 'vehicle_module_infos' in d:
            o.vehicle_module_infos = d['vehicle_module_infos']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFinanceQuotationQuotetradeTradedaystateBatchqueryModel(object):

    def __init__(self):
        self._begin_date = None
        self._end_date = None
        self._market = None

    @property
    def begin_date(self):
        return self._begin_date

    @begin_date.setter
    def begin_date(self, value):
        self._begin_date = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def market(self):
        return self._market

    @market.setter
    def market(self, value):
        self._market = value


    def to_alipay_dict(self):
        params = dict()
        if self.begin_date:
            if hasattr(self.begin_date, 'to_alipay_dict'):
                params['begin_date'] = self.begin_date.to_alipay_dict()
            else:
                params['begin_date'] = self.begin_date
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.market:
            if hasattr(self.market, 'to_alipay_dict'):
                params['market'] = self.market.to_alipay_dict()
            else:
                params['market'] = self.market
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFinanceQuotationQuotetradeTradedaystateBatchqueryModel()
        if 'begin_date' in d:
            o.begin_date = d['begin_date']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'market' in d:
            o.market = d['market']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserAgreementQueryModel(object):

    def __init__(self):
        self._agreement_no = None
        self._alipay_logon_id = None
        self._alipay_user_id = None
        self._external_agreement_no = None
        self._personal_product_code = None
        self._sign_scene = None
        self._third_party_type = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def alipay_logon_id(self):
        return self._alipay_logon_id

    @alipay_logon_id.setter
    def alipay_logon_id(self, value):
        self._alipay_logon_id = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def external_agreement_no(self):
        return self._external_agreement_no

    @external_agreement_no.setter
    def external_agreement_no(self, value):
        self._external_agreement_no = value
    @property
    def personal_product_code(self):
        return self._personal_product_code

    @personal_product_code.setter
    def personal_product_code(self, value):
        self._personal_product_code = value
    @property
    def sign_scene(self):
        return self._sign_scene

    @sign_scene.setter
    def sign_scene(self, value):
        self._sign_scene = value
    @property
    def third_party_type(self):
        return self._third_party_type

    @third_party_type.setter
    def third_party_type(self, value):
        self._third_party_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.alipay_logon_id:
            if hasattr(self.alipay_logon_id, 'to_alipay_dict'):
                params['alipay_logon_id'] = self.alipay_logon_id.to_alipay_dict()
            else:
                params['alipay_logon_id'] = self.alipay_logon_id
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.external_agreement_no:
            if hasattr(self.external_agreement_no, 'to_alipay_dict'):
                params['external_agreement_no'] = self.external_agreement_no.to_alipay_dict()
            else:
                params['external_agreement_no'] = self.external_agreement_no
        if self.personal_product_code:
            if hasattr(self.personal_product_code, 'to_alipay_dict'):
                params['personal_product_code'] = self.personal_product_code.to_alipay_dict()
            else:
                params['personal_product_code'] = self.personal_product_code
        if self.sign_scene:
            if hasattr(self.sign_scene, 'to_alipay_dict'):
                params['sign_scene'] = self.sign_scene.to_alipay_dict()
            else:
                params['sign_scene'] = self.sign_scene
        if self.third_party_type:
            if hasattr(self.third_party_type, 'to_alipay_dict'):
                params['third_party_type'] = self.third_party_type.to_alipay_dict()
            else:
                params['third_party_type'] = self.third_party_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAgreementQueryModel()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'alipay_logon_id' in d:
            o.alipay_logon_id = d['alipay_logon_id']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'external_agreement_no' in d:
            o.external_agreement_no = d['external_agreement_no']
        if 'personal_product_code' in d:
            o.personal_product_code = d['personal_product_code']
        if 'sign_scene' in d:
            o.sign_scene = d['sign_scene']
        if 'third_party_type' in d:
            o.third_party_type = d['third_party_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RuleMarkInfo(object):

    def __init__(self):
        self._comment = None
        self._mark_result = None
        self._rule_code = None
        self._status = None

    @property
    def comment(self):
        return self._comment

    @comment.setter
    def comment(self, value):
        self._comment = value
    @property
    def mark_result(self):
        return self._mark_result

    @mark_result.setter
    def mark_result(self, value):
        self._mark_result = value
    @property
    def rule_code(self):
        return self._rule_code

    @rule_code.setter
    def rule_code(self, value):
        self._rule_code = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.comment:
            if hasattr(self.comment, 'to_alipay_dict'):
                params['comment'] = self.comment.to_alipay_dict()
            else:
                params['comment'] = self.comment
        if self.mark_result:
            if hasattr(self.mark_result, 'to_alipay_dict'):
                params['mark_result'] = self.mark_result.to_alipay_dict()
            else:
                params['mark_result'] = self.mark_result
        if self.rule_code:
            if hasattr(self.rule_code, 'to_alipay_dict'):
                params['rule_code'] = self.rule_code.to_alipay_dict()
            else:
                params['rule_code'] = self.rule_code
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RuleMarkInfo()
        if 'comment' in d:
            o.comment = d['comment']
        if 'mark_result' in d:
            o.mark_result = d['mark_result']
        if 'rule_code' in d:
            o.rule_code = d['rule_code']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BusinessRelationShopInfo import BusinessRelationShopInfo


class AlipayBusinessRelationShopQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBusinessRelationShopQueryResponse, self).__init__()
        self._shop_infos = None

    @property
    def shop_infos(self):
        return self._shop_infos

    @shop_infos.setter
    def shop_infos(self, value):
        if isinstance(value, list):
            self._shop_infos = list()
            for i in value:
                if isinstance(i, BusinessRelationShopInfo):
                    self._shop_infos.append(i)
                else:
                    self._shop_infos.append(BusinessRelationShopInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayBusinessRelationShopQueryResponse, self).parse_response_content(response_content)
        if 'shop_infos' in response:
            self.shop_infos = response['shop_infos']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCreditPeUserContractSignResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditPeUserContractSignResponse, self).__init__()
        self._operate_time = None
        self._sign_id = None

    @property
    def operate_time(self):
        return self._operate_time

    @operate_time.setter
    def operate_time(self, value):
        self._operate_time = value
    @property
    def sign_id(self):
        return self._sign_id

    @sign_id.setter
    def sign_id(self, value):
        self._sign_id = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditPeUserContractSignResponse, self).parse_response_content(response_content)
        if 'operate_time' in response:
            self.operate_time = response['operate_time']
        if 'sign_id' in response:
            self.sign_id = response['sign_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ItemUnitInfo(object):

    def __init__(self):
        self._amount = None
        self._price = None
        self._spec = None
        self._title = None
        self._unit = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def spec(self):
        return self._spec

    @spec.setter
    def spec(self, value):
        self._spec = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def unit(self):
        return self._unit

    @unit.setter
    def unit(self, value):
        self._unit = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.spec:
            if hasattr(self.spec, 'to_alipay_dict'):
                params['spec'] = self.spec.to_alipay_dict()
            else:
                params['spec'] = self.spec
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.unit:
            if hasattr(self.unit, 'to_alipay_dict'):
                params['unit'] = self.unit.to_alipay_dict()
            else:
                params['unit'] = self.unit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ItemUnitInfo()
        if 'amount' in d:
            o.amount = d['amount']
        if 'price' in d:
            o.price = d['price']
        if 'spec' in d:
            o.spec = d['spec']
        if 'title' in d:
            o.title = d['title']
        if 'unit' in d:
            o.unit = d['unit']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySocialBaseBcgroupJoinedConsultModel(object):

    def __init__(self):
        self._business_id = None
        self._tenant_id = None
        self._user_id = None

    @property
    def business_id(self):
        return self._business_id

    @business_id.setter
    def business_id(self, value):
        self._business_id = value
    @property
    def tenant_id(self):
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, value):
        self._tenant_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_id:
            if hasattr(self.business_id, 'to_alipay_dict'):
                params['business_id'] = self.business_id.to_alipay_dict()
            else:
                params['business_id'] = self.business_id
        if self.tenant_id:
            if hasattr(self.tenant_id, 'to_alipay_dict'):
                params['tenant_id'] = self.tenant_id.to_alipay_dict()
            else:
                params['tenant_id'] = self.tenant_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialBaseBcgroupJoinedConsultModel()
        if 'business_id' in d:
            o.business_id = d['business_id']
        if 'tenant_id' in d:
            o.tenant_id = d['tenant_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o


